# NOTES ON CERTIFICATE LOCATIONS
#
# For systems with /etc/pki (e.g. FC4 and later):
# Certificate:	/etc/pki/dovecot/certs/dovecot.pem
# Key:		/etc/pki/dovecot/private/dovecot.pem
# Note that this is different from old Fedora packages, which generate
# the certificate at /etc/pki/dovecot/dovecot.pem but it is compatible
# with current Fedora packages
#
# For systems without /etc/pki (e.g. FC3 and older, RHEL4 and older):
# Certificate:	/usr/share/ssl/certs/dovecot.pem
# Key:		/usr/share/ssl/private/dovecot.pem

# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# Define prerel for betas, release candidates etc.
#global prerel	rc6

# Remember to bump dovecot_release and sieve_release with every release
%global dovecot_epoch 1
%global dovecot_version 2.1.17
%global dovecot_release %{?prerel:0.}1.0%{?prerel:.%{prerel}}.cf.%{__distinit}%{__distvers}
%global sieve_epoch 3
%global sieve_version 0.3.5
%global sieve_release 1.0.cf.%{__distinit}%{__distvers}
%global manage_sieve_epoch %{sieve_epoch}
%global manage_sieve_version %{sieve_version}
%global manage_sieve_release %{sieve_release}

# Snapshot used in Fedora needs autotools run
# We do this in a Fedora 16 buildroot to use the same autotools versions as
# upstream, and then create a "cooked" tarball that we use for real builds
%global fixup_pigeonhole_tarball 0
%global phsnap b2a456e15ed5
%if %{fixup_pigeonhole_tarball}
%global pigeonhole_dir dovecot-2-1-pigeonhole-%{phsnap}
%else
%global pigeonhole_dir dovecot-2.1-pigeonhole-%{sieve_version}
%endif

# sqlite-devel available from FC4, RHEL4 onwards
%if "%{__distinit}" == "fc" && %{__distvers} >= 4 || "%{__distinit}" == "rhel" && %{__distvers} >= 4
%global build_sqlite 1
%endif

# Suitably recent cURL and expat needed for solr support
%if "%{__distinit}" == "fc" && %{__distvers} >= 4
%global build_solr 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 5
%global build_solr 1
%endif

# Use systemd activation from Fedora 15
%if "%{__distinit}" == "fc" && %{__distvers} >= 15
%global use_systemd 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 7
%global use_systemd 1
%endif

# clucene-core-devel ≥ 2.3 needed for lucene plugin
%if "%{__distinit}" == "fc" && %{__distvers} >= 16
%global build_lucene 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 7
%global build_lucene 1
%endif

# Use private /tmp from Fedora 17
%if "%{__distinit}" == "fc" && %{__distvers} >= 18
%global private_tmp 1
%endif
%if "%{__distinit}" == "rhel" && %{__distvers} >= 7
%global private_tmp 1
%endif

# This macro only defined by default around Fedora 10 time
%{!?_initddir:%global _initddir %{_sysconfdir}/rc.d/init.d}

# Flag file used during package updates
%global restart_flag %{_localstatedir}/run/dovecot/dovecot-restart-after-rpm-install

Summary:	Dovecot IMAP server
Name:		dovecot
Epoch:		%{dovecot_epoch}
Version:	%{dovecot_version}
Release:	%{dovecot_release}
# dovecot itself is MIT, a few sources are PD
License:	MIT and GPLv2+
URL:		http://www.dovecot.org/
Group:		System Environment/Daemons
Source0:	http://www.dovecot.org/releases/2.1/dovecot-%{dovecot_version}%{?prerel:.%{prerel}}.tar.gz
Source1:	dovecot.init
Source2:	dovecot.pam
Source3:	dovecot.sysconfig

%if %{fixup_pigeonhole_tarball}
#Source8: http://hg.rename-it.nl/dovecot-2.1-pigeonhole/archive/tip.tar.bz2
# We use this ^^^ repository snapshot just renamed to contain last commit in name
Source8:	dovecot-2.1-pigeonhole-%{phsnap}.tar.bz2
BuildRequires:	automake, libtool, /usr/share/aclocal/iconv.m4
%else
# This tarball is created by running the autotools and "make dist" on the repository snapshot
#Source8:	dovecot-2.1-pigeonhole-%{sieve_version}-%{phsnap}.tar.bz2
Source8:	http://www.rename-it.nl/dovecot/2.1/dovecot-2.1-pigeonhole-%{sieve_version}.tar.gz
%endif

# Cope with /var/run on tmpfs
Source10:	dovecot.tmpfilesd

# Our own
Source14:	dovecot.conf.5

# Wait for network
Patch6:		dovecot-2.1.10-waitonline.patch
Source15:	prestartscript

# Fedora patches
Patch1:		dovecot-2.0-defaultconfig.patch
Patch2:		dovecot-1.0.beta2-mkcert-permissions.patch
Patch4:		dovecot-2.1.10-reload.patch
Patch5:		dovecot-2.1-privatetmp.patch

# Local patches
Patch500:	dovecot-2.1.6-SSLDIR.patch
Patch501:	dovecot-2.0.beta4-login-dir.patch
Patch502:	dovecot-2.0-mysqlconfig.patch
Patch503:	dovecot-2.1-pigeonhole-bzip2.patch
Patch504:	dovecot-2.1.17-fallocate64.patch
BuildRequires:	gcc-c++
BuildRequires:	openssl-devel, pam-devel, zlib-devel, bzip2-devel
BuildRequires:	openldap-devel, krb5-devel >= 1.3
BuildRequires:	pkgconfig
%if "%{__distinit}" == "fc" && %{__distvers} >= 10 || "%{__distinit}" == "rhel" && %{__distvers} >= 6
BuildRequires:	quota-devel
%endif
BuildRequires:	libcap-devel mysql-devel postgresql-devel %{?build_sqlite:sqlite-devel}
%if 0%{?build_solr}
# cURL library needed for Solr full text search support
# Actual buildreq may be curl-devel or libcurl-devel, depending on distribution
# Need expat too
BuildRequires:	/usr/include/curl/curl.h, expat-devel
%endif
%if 0%{?build_lucene}
BuildRequires:	clucene-core-devel >= 2.3
%endif
BuildRoot:	%{_tmppath}/%{name}-%{dovecot_version}-%{dovecot_release}-root-%(id -nu)
# openssl needed for mkcert.sh
Requires:	openssl
%if 0%{?use_systemd:1}
BuildRequires:	systemd-units
Requires: systemd
Requires(postun): systemd
%else
Requires: initscripts
Requires(postun): initscripts, /sbin/chkconfig
Requires(preun): /sbin/chkconfig
%endif

# Old packages merged into dovecot
Obsoletes:	dovecot-sqlite	< %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Obsoletes:	dovecot-ldap	< %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Obsoletes:	dovecot-gssapi	< %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Provides:	dovecot-sqlite	= %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Provides:	dovecot-ldap	= %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
Provides:	dovecot-gssapi	= %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

Requires(pre):	shadow-utils
Requires(post): openssl

# Figure out where ssl stuff goes
%global use_pki %(if [ -f %{_sysconfdir}/pki/tls/certs/ca-bundle.crt ]; then echo 1; else echo 0; fi)
%if %{use_pki}
%global ssldir %{_sysconfdir}/pki/dovecot
%else
%global ssldir %{_datadir}/ssl
%endif

# FC4, RHEL4 and older don't handle /var/run/dovecot/login/* properly, so we
# move it to /var/run/dovecot-login instead; F15 onwards has /var/run on tmpfs
# and doesn't explicitly clean /var/run so we have to use the fedora/rhel macros
%global move_login_dir %{?fedora}%{?rhel}0 < 50
%if %{move_login_dir}
%global login_dir dovecot-login
%else
%global login_dir dovecot/login
%endif

%global docdir %{_docdir}/dovecot-%{dovecot_version}
%global dovecot_uid 97
%global dovecot_gid 97

%description
Dovecot is an IMAP server for Linux/UNIX-like systems, written with security 
primarily in mind. It also contains a small POP3 server. It supports mail 
in either maildir or mbox formats.

%package devel
Summary:	Headers and config script needed for building plug-ins
Group:		Development/Libraries
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}
# The devel package needs to require the same packages as the main package buildrequires
Requires:	gcc-c++, openssl-devel, openldap-devel, pam-devel, pkgconfig, zlib-devel

%description devel
This package provides header files and configuration scripts required for
building plug-ins for the dovecot IMAP/POP3 server.

%package pigeonhole
Summary:	Sieve and Managesieve plug-in for dovecot
Group:		System Environment/Daemons
URL:		http://pigeonhole.dovecot.org/
License:	LGPLv2+
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

# Old packages merged into pigeonhole
Obsoletes:	dovecot-sieve < %{sieve_epoch}:%{sieve_version}-%{sieve_release}
Obsoletes:	dovecot-managesieve < %{manage_sieve_epoch}:%{manage_sieve_version}-%{manage_sieve_release}
Provides:	dovecot-sieve = %{sieve_epoch}:%{sieve_version}-%{sieve_release}
Provides:	dovecot-managesieve = %{manage_sieve_epoch}:%{manage_sieve_version}-%{manage_sieve_release}

%description pigeonhole
This package provides the sieve and managesieve plug-ins (version %{sieve_version})
for dovecot LDA.

%package pgsql
Summary:	Postgres SQL back end for dovecot
Group:		System Environment/Daemons
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

%description pgsql
This package provides the Postgres SQL back end for dovecot-auth etc.

%package mysql
Summary:	MySQL back end for dovecot
Group:		System Environment/Daemons
Requires:	dovecot = %{dovecot_epoch}:%{dovecot_version}-%{dovecot_release}

%description mysql
This package provides the MySQL back end for dovecot-auth etc.

%prep
%setup -q -n dovecot-%{dovecot_version}%{?prerel:.%{prerel}} -a 8

%patch1 -p1 -b .default-settings
%patch2 -p1 -b .mkcert-permissions
%patch4 -p1 -b .reload
%patch6 -p1 -b .waitonline

# Only use private /tmp from Fedora 18
%if 0%{?private_tmp}
%patch5 -p1 -b .privatetmp
%endif

# Fix lucene include path
%if 0%{?build_lucene}
sed -i '/DEFAULT_INCLUDES *=/s|$| '"$(pkg-config --cflags libclucene-core)|" src/plugins/fts-lucene/Makefile.in
%endif

# SSL certificates could be in /etc/pki or /usr/share/ssl
%patch500 -p1
sed -i -e 's#@SSLDIR@#%{ssldir}#g' doc/example-config/conf.d/10-ssl.conf doc/mkcert.sh

# Old distros don't clear subdirs of /var/run properly at boot time
%if %{move_login_dir}
%patch501
%endif

# Old distros have broken mysql_config scripts: fix up their output
%patch502 -p1

# We want to make a bzipped tarball
%if %{fixup_pigeonhole_tarball}
cd %{pigeonhole_dir}
%patch503 -p2
cd -
%endif

# glibc 2.10 in F-11 has no fallocate64() in 32-bit release
# http://bugzilla.redhat.com/500487
%patch504

# PAM Configuration:
# Default PAM configuration file uses password-auth common config;
# revert to system-auth if password-auth is not available
cp -p %{SOURCE2} .
if [ ! -f /etc/pam.d/password-auth ]; then
	sed -i -e s/password-auth/system-auth/ dovecot.pam
fi
# The "include" syntax used in our PAM configuration file was introduced in
# PAM 0.78 and is therefore supported in FC-5 and EL-5 onwards; older
# distributions such as EL-4 (PAM 0.77) need to fall back to using the
# now-deprecated pam_stack module. Since the pam-devel package doesn't
# include a pkgconfig file from which we could check the version number, we
# instead check for the absence of the file /etc/pam.d/config-util, which is
# present in all PAM packages from 0.80 onwards and acts as a useful
# indicator of the need to fall back to pam_stack.
[ ! -f /etc/pam.d/config-util ] && sed -i -e \
	's/include[[:space:]]*system-auth/required'\ \ \ \ \ 'pam_stack.so service=system-auth/' \
	dovecot.pam

# Copy in dovecot.conf manpage
cp -p %{SOURCE14} .

%build
# Required for fdpass.c line 125,190: dereferencing type-punned pointer will break strict-aliasing rules
export CFLAGS="%{optflags} -fno-strict-aliasing"

# Harden the build if supported
%if 0%{?fedora} > 15 || 0%{?rhel} > 6
%global _hardened_build 1
export CFLAGS="%{__global_cflags} -fno-strict-aliasing"
export LDFLAGS="-Wl,-z,now -Wl,-z,relro %{__global_ldflags}"
%endif

%configure									\
			INSTALL_DATA="install -c -p -m644"			\
			--docdir=%{_docdir}/dovecot-%{version}			\
			--disable-dependency-tracking				\
			--disable-rpath						\
			--disable-static					\
			--with-bzlib						\
			--with-docs						\
			--with-gssapi=plugin					\
			--with-ldap=plugin					\
			--with-libcap						\
%{?build_lucene:	--with-lucene}						\
			--with-mysql						\
			--with-nss						\
			--with-pam						\
			--with-pgsql						\
			--with-shadow						\
%{?build_solr:		--with-solr}						\
%{?build_sqlite:	--with-sqlite}						\
			--with-sql=plugin					\
			--with-ssl=openssl					\
			--with-ssldir=%{ssldir}					\
%{?use_systemd:		--with-systemdsystemunitdir=%{_unitdir}}		\
			--with-zlib
make %{?_smp_mflags}

# Pigeonhole
cd %{pigeonhole_dir}
%if %{fixup_pigeonhole_tarball}
touch ChangeLog
autoreconf -fiv
%endif
%configure							\
			INSTALL_DATA="install -c -p -m644"	\
			--disable-static			\
			--with-dovecot=../
%if %{fixup_pigeonhole_tarball}
make dist
mv	dovecot-2.1-pigeonhole-%{sieve_version}.tar.bz2 \
	dovecot-2.1-pigeonhole-%{sieve_version}-%{phsnap}.tar.bz2
%endif
make %{?_smp_mflags}
cd -

%install
rm -rf %{buildroot}

# Install dovecot
make install DESTDIR=%{buildroot}

# We'll package the dovecot documentation ourselves
mv %{buildroot}%{_docdir}/dovecot-%{dovecot_version} $(pwd)/dovecot-docs

# Install Pigeonhole
cd %{pigeonhole_dir}
make install DESTDIR=%{buildroot}
cd -

# We'll package the pigeonhole documentation ourselves too
mv %{buildroot}%{_docdir}/dovecot-%{dovecot_version} $(pwd)/pigeonhole-docs
cd %{pigeonhole_dir}
ln AUTHORS ChangeLog COPYING COPYING.LGPL INSTALL NEWS README ../pigeonhole-docs/
cd -

# Create state directories with appropriate permissions
mkdir -p %{buildroot}%{_localstatedir}/run/dovecot/empty
chmod 755 %{buildroot}%{_localstatedir}/run/dovecot
chmod 755 %{buildroot}%{_localstatedir}/run/dovecot/empty
mkdir -p %{buildroot}%{_localstatedir}/run/%{login_dir}
chmod 750 %{buildroot}%{_localstatedir}/run/%{login_dir}
mkdir -p %{buildroot}%{_localstatedir}/lib/dovecot
chmod 750 %{buildroot}%{_localstatedir}/lib/dovecot

# Make sure state directories are created at boot time for systems
# with /var/run on tmpfs, else install the SysV initscript
%if 0%{?use_systemd:1}
install -p -D -m 644 %{SOURCE10} %{buildroot}%{_prefix}/lib/tmpfiles.d/dovecot.conf
%else
install -p -D -m 755 %{SOURCE1} %{buildroot}%{_initddir}/dovecot
install -p -D -m 600 %{SOURCE3} %{buildroot}%{_sysconfdir}/sysconfig/dovecot
%endif

# Install the certificate generating script in %%{_libexecdir}/dovecot
install -p -m 755 doc/mkcert.sh %{buildroot}%{_libexecdir}/dovecot/mkcert.sh

# Install waitonline script
install -p -D -m 755 %{SOURCE15} %{buildroot}%{_libexecdir}/dovecot/prestartscript

# Generate ghost .pem files
mkdir -p %{buildroot}%{ssldir}/{certs,private}
: > %{buildroot}%{ssldir}/certs/dovecot.pem
: > %{buildroot}%{ssldir}/private/dovecot.pem

# Install dovecot configuration and dovecot-openssl.cnf
mkdir -p %{buildroot}%{_sysconfdir}/dovecot/conf.d
mkdir -p %{buildroot}%{ssldir}
install -p -m 644 dovecot-docs/example-config/dovecot.conf %{buildroot}%{_sysconfdir}/dovecot
install -p -m 644 dovecot-docs/example-config/conf.d/*.conf %{buildroot}%{_sysconfdir}/dovecot/conf.d
install -p -m 644 dovecot-docs/example-config/conf.d/*.conf.ext %{buildroot}%{_sysconfdir}/dovecot/conf.d
install -p -m 644 pigeonhole-docs/example-config/conf.d/*.conf %{buildroot}%{_sysconfdir}/dovecot/conf.d
install -p -m 644 pigeonhole-docs/example-config/conf.d/*.conf.ext %{buildroot}%{_sysconfdir}/dovecot/conf.d || :
install -p -m 644 doc/dovecot-openssl.cnf %{buildroot}%{ssldir}/dovecot-openssl.cnf

# PAM Configuration
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -p -m 644 dovecot.pam %{buildroot}%{_sysconfdir}/pam.d/dovecot

# Install additional manpages
install -p -D -m 644 dovecot.conf.5 %{buildroot}%{_mandir}/man5/dovecot.conf.5

# Blow away static libraries
find %{buildroot}%{_libdir}/dovecot -name '*.a' -exec rm -f {} \;

# Blow away libtool archives
find %{buildroot}%{_libdir}/dovecot -name '*.la' -exec rm -f {} \;

# Blow away unwanted documentation
rm %{buildroot}%{_sysconfdir}/dovecot/README
cd dovecot-docs
rm securecoding.txt thread-refs.txt
cd -

%check
make check
make -C %{pigeonhole_dir} check

%clean
rm -rf %{buildroot}

%pre
# Create account for dovecot to run as
/usr/bin/getent group dovecot > /dev/null || \
	/usr/sbin/groupadd -g %{dovecot_gid} -r dovecot
/usr/bin/getent passwd dovecot > /dev/null || \
	/usr/sbin/useradd -r -u %{dovecot_uid} -g dovecot \
		-d %{_libexecdir}/dovecot -M -s /sbin/nologin \
		-c "Dovecot IMAP Server" dovecot
/usr/bin/getent group dovenull > /dev/null || \
	/usr/sbin/groupadd -r dovenull
/usr/bin/getent passwd dovenull > /dev/null || \
	/usr/sbin/useradd -r -g dovenull \
		-d %{_libexecdir}/dovecot -s /sbin/nologin \
		-c "Dovecot's unauthorized user" dovenull

# Do not let dovecot run during upgrade (#134325)
if [ "$1" = "2" ]; then
	rm -f %{restart_flag}
%if 0%{?use_systemd:1}
	/bin/systemctl is-active dovecot.service &>/dev/null && touch %{restart_flag} || :
	/bin/systemctl stop dovecot.service &>/dev/null
%else
	/sbin/service dovecot status &>/dev/null && touch %{restart_flag} || :
	/sbin/service dovecot stop &>/dev/null
%endif
fi

%post
if [ $1 -eq 1 ]; then
%if 0%{?use_systemd:1}
	/bin/systemctl daemon-reload &> /dev/null || :
%else
	/sbin/chkconfig --add dovecot || :
%endif
fi

%if %{use_pki}
# Migrate SSL certificates from old locations if present
# Use cp rather than mv to avoid breakage of existing configuration
[ -f %{ssldir}/dovecot.pem -a ! -e %{ssldir}/certs/dovecot.pem ] &&
	cp -p %{ssldir}/dovecot.pem %{ssldir}/certs/dovecot.pem
[ -f %{_datadir}/ssl/certs/dovecot.pem -a ! -e %{ssldir}/certs/dovecot.pem ] &&
	cp -p %{_datadir}/ssl/certs/dovecot.pem %{ssldir}/certs/dovecot.pem || :
[ -f %{_datadir}/ssl/private/dovecot.pem -a ! -e %{ssldir}/private/dovecot.pem ] &&
	cp -p %{_datadir}/ssl/private/dovecot.pem %{ssldir}/private/dovecot.pem || :
%endif

# Create SSL keys/certs
[ ! -f %{ssldir}/certs/dovecot.pem ] && %{_libexecdir}/dovecot/mkcert.sh &> /dev/null || :

# Create SSL parameters
[ ! -f %{_localstatedir}/lib/dovecot/ssl-parameters.dat ] && %{_libexecdir}/dovecot/ssl-params &>/dev/null

exit 0

%preun
if [ $1 = 0 ]; then
%if 0%{?use_systemd:1}
	/bin/systemctl disable dovecot.service dovecot.socket &> /dev/null || :
	/bin/systemctl stop dovecot.service dovecot.socket &> /dev/null || :
%else
	%{_initddir}/dovecot stop &> /dev/null || :
	/sbin/chkconfig --del dovecot
%endif
	rm -rf %{_localstatedir}/run/dovecot
fi

%postun
# service restarted in %%postun rather than %%post for the benefit of people doing composes in chroots
%if 0%{?use_systemd:1}
/bin/systemctl daemon-reload &> /dev/null || :
%endif
if [ "$1" -ge "1" -a -e %{restart_flag} ]; then
%if 0%{?use_systemd:1}
	/bin/systemctl start dovecot.service &> /dev/null || :
%else
	%{_initddir}/dovecot start &> /dev/null || :
%endif
	rm -f %{restart_flag}
fi

%posttrans
# dovecot should be started again in %%postun, but it's not executed on reinstall;
# if it was already started, restart_flag won't be here, so it's ok to test it again
if [ -e %{restart_flag} ]; then
%if 0%{?use_systemd:1}
	/bin/systemctl start dovecot.service &> /dev/null || :
%else
	%{_initddir}/dovecot start &> /dev/null || :
%endif
	rm -f %{restart_flag}
fi

%files
%defattr(-,root,root,-)
%if 0%{?use_systemd:1}
%{_prefix}/lib/tmpfiles.d/dovecot.conf
%{_unitdir}/dovecot.service
%{_unitdir}/dovecot.socket
%else
%{_initddir}/dovecot
%attr(0600,root,root) %config(noreplace) %{_sysconfdir}/sysconfig/dovecot
%endif
%doc dovecot-docs/* AUTHORS ChangeLog COPYING COPYING.LGPL COPYING.MIT NEWS README
%dir %{_sysconfdir}/dovecot/
%dir %{_sysconfdir}/dovecot/conf.d/
%config(noreplace) %{_sysconfdir}/dovecot/dovecot.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-checkpassword.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-auth.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-director.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-logging.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-mail.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-master.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/10-ssl.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/15-lda.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/15-mailboxes.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-imap.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-lmtp.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-pop3.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-acl.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-plugin.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-quota.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-deny.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-ldap.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-master.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-passwdfile.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-sql.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-static.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-system.conf.ext
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/auth-vpopmail.conf.ext
%config(noreplace) %{_sysconfdir}/pam.d/dovecot
%config(noreplace) %{ssldir}/dovecot-openssl.cnf
%if %{use_pki}
%dir %{ssldir}/
%dir %{ssldir}/certs/
%dir %{ssldir}/private/
%endif
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssldir}/certs/dovecot.pem
%attr(0600,root,root) %ghost %config(missingok,noreplace) %verify(not md5 size mtime) %{ssldir}/private/dovecot.pem
%{_bindir}/doveadm
%{_bindir}/doveconf
%{_bindir}/dsync
%{_sbindir}/dovecot
%dir %{_libexecdir}/dovecot/
%{_libexecdir}/dovecot/aggregator
%{_libexecdir}/dovecot/anvil
%{_libexecdir}/dovecot/auth
%{_libexecdir}/dovecot/checkpassword-reply
%{_libexecdir}/dovecot/config
%{_libexecdir}/dovecot/decode2text.sh
%{_libexecdir}/dovecot/deliver
%{_libexecdir}/dovecot/dict
%{_libexecdir}/dovecot/director
%{_libexecdir}/dovecot/dns-client
%{_libexecdir}/dovecot/doveadm-server
%{_libexecdir}/dovecot/dovecot-lda
%{_libexecdir}/dovecot/gdbhelper
%{_libexecdir}/dovecot/imap
%{_libexecdir}/dovecot/imap-login
%{_libexecdir}/dovecot/indexer
%{_libexecdir}/dovecot/indexer-worker
%{_libexecdir}/dovecot/ipc
%{_libexecdir}/dovecot/lmtp
%{_libexecdir}/dovecot/log
%{_libexecdir}/dovecot/maildirlock
%{_libexecdir}/dovecot/mkcert.sh
%{_libexecdir}/dovecot/pop3
%{_libexecdir}/dovecot/pop3-login
%{_libexecdir}/dovecot/prestartscript
%{_libexecdir}/dovecot/quota-status
%{_libexecdir}/dovecot/rawlog
%{_libexecdir}/dovecot/replicator
%{_libexecdir}/dovecot/script
%{_libexecdir}/dovecot/script-login
%{_libexecdir}/dovecot/ssl-params
%{_libexecdir}/dovecot/stats
%{_libexecdir}/dovecot/xml2text
# Note: %%{_libdir}/dovecot/*.so are plug-ins, not devel files
%dir %{_libdir}/dovecot/
%dir %{_libdir}/dovecot/auth/
%dir %{_libdir}/dovecot/dict/
%dir %{_libdir}/dovecot/doveadm/
%dir %{_libdir}/dovecot/settings/
%{_libdir}/dovecot/auth/libauthdb_imap.so
%{_libdir}/dovecot/auth/libauthdb_ldap.so
%{_libdir}/dovecot/auth/libmech_gssapi.so
%if 0%{?build_sqlite}
%{_libdir}/dovecot/libdriver_sqlite.so
%{_libdir}/dovecot/auth/libdriver_sqlite.so
%{_libdir}/dovecot/dict/libdriver_sqlite.so
%endif
%{_libdir}/dovecot/doveadm/lib10_doveadm_acl_plugin.so
%{_libdir}/dovecot/doveadm/lib10_doveadm_expire_plugin.so
%{_libdir}/dovecot/doveadm/lib10_doveadm_quota_plugin.so
%{_libdir}/dovecot/doveadm/lib10_doveadm_zlib_plugin.so
%{_libdir}/dovecot/doveadm/lib20_doveadm_fts_plugin.so
%if 0%{?build_lucene}
%{_libdir}/dovecot/doveadm/lib20_doveadm_fts_lucene_plugin.so
%endif
%{_libdir}/dovecot/libdovecot.so.0
%{_libdir}/dovecot/libdovecot.so.0.0.0
%{_libdir}/dovecot/libdovecot-lda.so.0
%{_libdir}/dovecot/libdovecot-lda.so.0.0.0
%{_libdir}/dovecot/libdovecot-login.so.0
%{_libdir}/dovecot/libdovecot-login.so.0.0.0
%{_libdir}/dovecot/libdovecot-sieve.so.0
%{_libdir}/dovecot/libdovecot-sieve.so.0.0.0
%{_libdir}/dovecot/libdovecot-sql.so.0
%{_libdir}/dovecot/libdovecot-sql.so.0.0.0
%{_libdir}/dovecot/libdovecot-ssl.so.0
%{_libdir}/dovecot/libdovecot-ssl.so.0.0.0
%{_libdir}/dovecot/libdovecot-storage.so.0
%{_libdir}/dovecot/libdovecot-storage.so.0.0.0
%{_libdir}/dovecot/lib01_acl_plugin.so
%{_libdir}/dovecot/lib02_imap_acl_plugin.so
%{_libdir}/dovecot/lib02_lazy_expunge_plugin.so
%{_libdir}/dovecot/lib05_pop3_migration_plugin.so
%{_libdir}/dovecot/lib05_snarf_plugin.so
%{_libdir}/dovecot/lib10_quota_plugin.so
%{_libdir}/dovecot/lib11_imap_quota_plugin.so
%{_libdir}/dovecot/lib11_trash_plugin.so
%{_libdir}/dovecot/lib15_notify_plugin.so
%{_libdir}/dovecot/lib20_autocreate_plugin.so
%{_libdir}/dovecot/lib20_expire_plugin.so
%{_libdir}/dovecot/lib20_fts_plugin.so
%{_libdir}/dovecot/lib20_listescape_plugin.so
%{_libdir}/dovecot/lib20_mail_log_plugin.so
%{_libdir}/dovecot/lib20_mailbox_alias_plugin.so
%{_libdir}/dovecot/lib20_replication_plugin.so
%{_libdir}/dovecot/lib20_virtual_plugin.so
%{_libdir}/dovecot/lib20_zlib_plugin.so
%if 0%{?build_lucene}
%{_libdir}/dovecot/lib21_fts_lucene_plugin.so
%endif
%if 0%{?build_solr}
%{_libdir}/dovecot/lib21_fts_solr_plugin.so
%endif
%{_libdir}/dovecot/lib21_fts_squat_plugin.so
%{_libdir}/dovecot/lib30_imap_zlib_plugin.so
%{_libdir}/dovecot/lib90_stats_plugin.so
%{_libdir}/dovecot/lib95_imap_stats_plugin.so
%attr(0755,root,dovecot) %dir %{_localstatedir}/run/dovecot/
%dir %{_localstatedir}/run/dovecot/empty/
%attr(0750,root,dovenull) %dir %{_localstatedir}/run/%{login_dir}/
%attr(0750,dovecot,dovecot) %dir %{_localstatedir}/lib/dovecot/
%{_mandir}/man1/deliver.1*
%{_mandir}/man1/doveadm.1*
%{_mandir}/man1/doveadm-altmove.1*
%{_mandir}/man1/doveadm-auth.1*
%{_mandir}/man1/doveadm-config.1*
%{_mandir}/man1/doveadm-director.1*
%{_mandir}/man1/doveadm-dump.1*
%{_mandir}/man1/doveadm-expunge.1*
%{_mandir}/man1/doveadm-fetch.1*
%{_mandir}/man1/doveadm-force-resync.1*
%{_mandir}/man1/doveadm-help.1*
%{_mandir}/man1/doveadm-import.1*
%{_mandir}/man1/doveadm-index.1*
%{_mandir}/man1/doveadm-instance.1*
%{_mandir}/man1/doveadm-kick.1*
%{_mandir}/man1/doveadm-log.1*
%{_mandir}/man1/doveadm-mailbox.1*
%{_mandir}/man1/doveadm-mount.1*
%{_mandir}/man1/doveadm-move.1*
%{_mandir}/man1/doveadm-penalty.1*
%{_mandir}/man1/doveadm-purge.1*
%{_mandir}/man1/doveadm-pw.1*
%{_mandir}/man1/doveadm-quota.1*
%{_mandir}/man1/doveadm-reload.1*
%{_mandir}/man1/doveadm-search.1*
%{_mandir}/man1/doveadm-stop.1*
%{_mandir}/man1/doveadm-user.1*
%{_mandir}/man1/doveadm-who.1*
%{_mandir}/man1/doveconf.1*
%{_mandir}/man1/dovecot.1*
%{_mandir}/man1/dovecot-lda.1*
%{_mandir}/man1/dsync.1*
%{_mandir}/man5/dovecot.conf.5*
%{_mandir}/man7/doveadm-search-query.7*

%files devel
%defattr(-,root,root,-)
%{_includedir}/dovecot/
%{_datadir}/aclocal/dovecot.m4
%{_libdir}/dovecot/dovecot-config
%{_libdir}/dovecot/libdovecot.so
%{_libdir}/dovecot/libdovecot-lda.so
%{_libdir}/dovecot/libdovecot-login.so
%{_libdir}/dovecot/libdovecot-sieve.so
%{_libdir}/dovecot/libdovecot-sql.so
%{_libdir}/dovecot/libdovecot-ssl.so
%{_libdir}/dovecot/libdovecot-storage.so

%files pigeonhole
%defattr(-,root,root,-)
%doc pigeonhole-docs/*
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/20-managesieve.conf
%config(noreplace) %{_sysconfdir}/dovecot/conf.d/90-sieve.conf
%{_bindir}/sievec
%{_bindir}/sieve-dump
%{_bindir}/sieve-filter
%{_bindir}/sieve-test
%{_libdir}/dovecot/lib90_sieve_plugin.so
%{_libdir}/dovecot/settings/libmanagesieve_settings.so
%{_libdir}/dovecot/settings/libmanagesieve_login_settings.so
%{_libexecdir}/dovecot/managesieve
%{_libexecdir}/dovecot/managesieve-login
%{_mandir}/man1/sievec.1*
%{_mandir}/man1/sieved.1*
%{_mandir}/man1/sieve-dump.1*
%{_mandir}/man1/sieve-filter.1*
%{_mandir}/man1/sieve-test.1*
%{_mandir}/man7/pigeonhole.7*

%files mysql
%defattr(-,root,root,-)
%{_libdir}/dovecot/libdriver_mysql.so
%{_libdir}/dovecot/auth/libdriver_mysql.so
%{_libdir}/dovecot/dict/libdriver_mysql.so

%files pgsql
%defattr(-,root,root,-)
%{_libdir}/dovecot/libdriver_pgsql.so
%{_libdir}/dovecot/auth/libdriver_pgsql.so
%{_libdir}/dovecot/dict/libdriver_pgsql.so

%changelog
* Tue Aug  6 2013 Paul Howarth <paul@city-fan.org> 1:2.1.17-1.0.cf
- dovecot updated to 2.1.17:
  - zlib: keep the last read mail uncompressed in a temporary file; this
    significantly improves performance when IMAP client does small partial
    fetches for a large mail
  - acl: optionally get default ACL's for private/shared namespaces from user's
    INBOX (plugin { acl_defaults_from_inbox = yes })
  - case-insensitive unicode character comparisons weren't all working as they
    should
  - maildir: fixed handling over 26 keywords in a mailbox
  - auth: don't crash in non-PLAIN/LOGIN auth mechanism if master user login is
    attempted without any master passdbs configured
- pigeonhole updated to 0.3.5:
  - changed error handling to be less of a nuisance for administrators: strictly
    user-caused errors are only reported in user log, and some errors are logged
    as info instead
  - Sieve: changed behavior of redirect in case of a duplicate message delivery
    or a mail loop (see NEWS for additional detail)
  - Sieve vnd.dovecot.duplicate extension: added new features to the duplicate
    test, making it possible to manually compose the key value for duplicate
    checking; this extension is in the process of being standardized:
    https://tools.ietf.org/html/draft-bosch-sieve-duplicate-01
  - Sieve date extension: generate warning when invalid date part is specified
  - Sieve editheader extension: fixed crash occuring when addheader :last was
    used
  - Sieve editheader extension: fixed interaction with the Sieve body
    extension; if used together, the deleteheader action could fail after a
    body test was performed
  - Sieve include extension: fixed missing error cleanup that caused a resource
    leak
  - Sieve vacation extension: fixed determination of From: address for when
    sieve_vacation_dont_check_recipient is active
  - Sieve tools: the -D option wasn't enabled and documented for all tools
  - Sieve dict script storage: fixed potential segfault occuring when dict
    initialization fails
  - ManageSieve: fixed bug in skipping of CRLF at end of AUTHENTICATE command
  - ManageSieve: fixed handling of unkown commands pre-login
  - Fixed compile on Mageia Linux
  - Test suite: fixed a time zone dependency in the Sieve date extension tests
- update fallocate64 patch

* Tue Apr  9 2013 Paul Howarth <paul@city-fan.org> 1:2.1.16-2.0.cf
- make sure dovecot executables are hardened

* Fri Apr  5 2013 Paul Howarth <paul@city-fan.org> 1:2.1.16-1.0.cf
- dovecot updated to 2.1.16:
  - added quota-status policy service for Postfix
  - added 'doveadm batch' command to run multiple commands before moving
    onto the next user (useful only with -A and -u <usermask>)
  - added forwards compatibility for v2.2 index files
  - mdbox: index rebuilding crashed in some situations
  - fixed a race condition with setting \Recent flags
  - fixed a crash when decoding a specific message (decoding is done for
    SEARCH TEXT/BODY and with full text search indexing, so this couldn't
    fully DoS a user)
- update fallocate64 patch
- package new quota-status helper

* Fri Mar  1 2013 Paul Howarth <paul@city-fan.org> 1:2.1.15-2.0.cf
- do not print error when NetworkManager is not installed (#916456)

* Sun Feb 10 2013 Paul Howarth <paul@city-fan.org> 1:2.1.15-1.0.cf
- dovecot updated to 2.1.15:
  - v2.1.14: dovecot.index.cache fixes caused it to use more disk I/O and
    memory than necessary

* Thu Feb  7 2013 Paul Howarth <paul@city-fan.org> 1:2.1.14-2.0.cf
- do relro-hardened build from F-16 onwards
- use %%{_unitdir} macro for systemd unit file directory

* Thu Jan 31 2013 Paul Howarth <paul@city-fan.org> 1:2.1.14-1.0.cf
- dovecot updated to 2.1.14:
  - doveadm acl recalc command added
  - v2.1.11+ had a race condition where it sometimes overwrote data in the
    dovecot.index.cache file, which could have caused Dovecot to return the
    same cached data to two different messages
  - mdbox: fixes for handling of duplicate GUIDs during index rebuild
- update fallocate64 patch

* Mon Jan  7 2013 Paul Howarth <paul@city-fan.org> 1:2.1.13-1.0.cf
- dovecot updated to 2.1.13:
  - some fixes to cache file changes in v2.1.11
  - fts-solr: overlong UTF8 sequences in mails were rejected by Solr and caused
    the mails to not be indexed
  - virtual storage: sorting mailbox by from/to/cc/bcc didn't work

* Fri Nov 30 2012 Paul Howarth <paul@city-fan.org> 1:2.1.12-1.0.cf
- dovecot updated to 2.1.12:
  - dovecot-config in v2.1.11 caused build problems with Pigeonhole

* Thu Nov 29 2012 Paul Howarth <paul@city-fan.org> 1:2.1.11-1.0.cf
- dovecot updated to 2.1.11:
  - lmtp/lda: dovecot.index.cache file is no longer fully mapped to memory,
    allowing mail deliveries to work even if the file is huge
  - auth: userdb passwd lookups are now done by auth worker processes instead
    of auth master process (as it was documented, but accidentally didn't work
    that way)
  - lmtp: lmtp_rcpt_check_quota=yes setting checks quota on RCPT TO
  - lmtp: after successful proxying RCPT TO, the next one to a nonexistent user
    gave tempfail error instead of "user not found"
  - lmtp proxy: fixed hanging if remote server was down
  - imap: fixed crash when SEARCH contained multiple KEYWORD parameters
  - doveadm: various fixes to handling doveadm-server connections
  - -i <instance name> parameter for Dovecot tools didn't work correctly
  - director was somewhat broken in v2.1.10; this version also includes various
    reliability enhancements
  - auth: passdb imap was broken in v2.1.10
- update fallocate64 patch

* Tue Nov 20 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-4.0.cf
- do not crash during mail search (#861742)
- fix bogus dates in spec changelog entries

* Mon Nov 12 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-3.0.cf
- fix network still not ready race condition (#871623)

* Sun Nov  4 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-2.0.cf
- add reload command to service file
- disable PrivateTmp prior to F-18 (#851131)

* Wed Sep 19 2012 Paul Howarth <paul@city-fan.org> 1:2.1.10-1.0.cf
- dovecot updated to 2.1.10:
  - imap: implemented THREAD=ORDEREDSUBJECT extension
  - added "doveadm exec" command to easily execute commands from libexec_dir,
    e.g. "doveadm exec imap -u user@domain"
  - added "doveadm copy" command
  - doveadm copy/move: added optional user parameter to specify the source
    username; this allows easily copying mails between different users
  - added namespace { disabled } setting to quickly enable/disable namespaces;
    this is especially useful when its value is returned by userdb
  - added mailbox_alias plugin, which allows creating mailbox aliases using
    symlinks
  - imapc storage: added imapc_max_idle_time setting to force activity on
    connection
  - fts-solr: expunging multiple messages is now faster
  - director: in some conditions director may have disconnected from another
    director (without logging about it), thinking it was sending invalid data
  - imap: various fixes to listing mailboxes
  - pop3-migration plugin: avoid disconnection from POP3 server due to idling
  - login processes crashed if there were a lot of local {} or remote {}
    settings blocks
- pigeonhole updated to 0.3.3:
  - sieve-refilter tool: improved man page documentation by explicitly
    specifying the syntax used for mailbox arguments
  - sieve: spamtest and virustest extensions: improved trace debugging of score
    calculation
  - sieve: made error messages about exceeding the maximum number of actions
    more verbose
  - sieve tools: fixed problems with running as root: sievec and sieve-dump now
    ignore mail_uid and mail_gid settings when run as root.
  - sieve: fixed bug in action accounting (for limit checking): increase action
    instance count only when an action is actually created
  - sieve: include extension: fixed namespace separation of :global and
    :personal scripts
  - managesieve: fixed segfault bug triggered by CHECKSCRIPT command
  - fixed linking with ld.gold
  - fixed several Clang compile warnings and a few potential bugs

* Sun Aug 19 2012 Paul Howarth <paul@city-fan.org> 1:2.1.9-2.0.cf
- rebuild

* Thu Aug  2 2012 Paul Howarth <paul@city-fan.org> 1:2.1.9-1.0.cf
- dovecot updated to 2.1.9:
  - mail-log plugin: log mailbox names with UTF-8 everywhere (instead of mUTF-7
    in some places and UTF-8 in other places)
  - director: changed director_username_hash setting's default from %%u to %%Lu
    (= lowercase usernames); this doesn't break any existing installations, but
    might fix some of them
  - doveadm: added "auth cache flush [<username>]" command
  - implemented dict passdb/userdb
  - implemented Redis and memcached dict backends, which can be used as auth
    backends; Redis can also be used as dict-quota backend
  - added plugin { quota_ignore_save_errors=yes } setting to allow saving a
    mail when quota lookup fails with temporary failure
  - full text search indexing might have failed for some messages, always
    causing indexer-worker process to run out of memory
  - fts-lucene: fixed handling SEARCH HEADER FROM/TO/SUBJECT/CC/BCC when the
    header wasn't lowercased
  - fts-squat: fixed crash when searching a virtual mailbox
  - pop3: fixed assert crash when doing UIDL on empty mailbox on some setups
  - auth: GSSAPI RFC compliancy and error handling fixes
  - various fixes related to handling shared namespaces

* Tue Jul 24 2012 Paul Howarth <paul@city-fan.org> 1:2.1.8-3.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Wed Jul  4 2012 Paul Howarth <paul@city-fan.org> 1:2.1.8-2.1.cf
- move tmpfiles.d config from %%{_sysconfdir} to %%{_prefix}/lib

* Tue Jul  3 2012 Paul Howarth <paul@city-fan.org> 1:2.1.8-2.0.cf
- dovecot updated to 2.1.8:
  - pop3c: added pop3c_master_user setting
  - imap: mailbox names were accidentally sent as UTF-8 instead of mUTF-7 in
    previous v2.1.x releases for STATUS, MYRIGHTS and GETQUOTAROOT commands
  - lmtp proxy: don't timeout connections too early when mail has a lot of
    RCPT TOs
  - director: don't crash if the director is working alone
  - shared mailboxes: avoid doing "@domain" userdb lookups
  - doveadm: fixed crash with proxying some commands
  - fts-squat: fixed handling multiple SEARCH parameters
  - imapc: fixed a crash when message had more than 8 keywords
  - imapc: don't crash on APPEND/COPY if server doesn't support UIDPLUS
- pigeonhole updated to 0.3.1:
  - added support for retrieving Sieve scripts from dict lookup
  - incorporated the sieve_duplicate plugin into main Pigeonhole tree as a
    normal extension (vnd.dovecot.duplicate)
  - added support for specifying multiple sieve_before and sieve_after paths
  - added a "session ID" string for managesieve connections, available in
    %%{session} variable (analogous to Dovecot change)
  - fixed several small issues, including a few potential segfault bugs, based
    on static source code analysis
  - ManageSieve: changed use of EPROTO error to EIO in ManageSieve string stream
    implementation because it is apparently not known in BSD
  - gave stamp.h.in (needed for autotools) some content to prevent it from
    disappearing in patch files
  - fixed bug that caused a SunStudio CC compile failure
- update fallocate64 patch

* Mon Jul  2 2012 Paul Howarth <paul@city-fan.org> 1:2.1.7-5.0.cf
- make quota work with NFS-mounted mailboxes (F-10, EL-6 onwards)

* Fri Jun 22 2012 Paul Howarth <paul@city-fan.org> 1:2.1.7-4.0.cf
- do not let dovecot run during upgrade (#134325)

* Wed May 30 2012 Paul Howarth <paul@city-fan.org> 1:2.1.7-2.0.cf
- dovecot updated to 2.1.7:
  - LDAP: compatibility fix for v2.0 - if attributes contain
    ldapAttr=key=template%$ and ldapAttr doesn't exist, skip the key instead
    of using "template" value with empty %$ part for the key
  - pop3: added pop3_uidl_duplicates setting for changing the behavior for
    duplicate UIDLs
  - director: added "doveadm director ring remove" command
  - director: don't crash with quickly disconnecting incoming director
    connections
  - mdbox: if mail was originally saved to non-INBOX, and namespace prefix is
    non-empty, don't assert-crash when rebuilding indexes
  - sdbox: don't use more fds than necessary when copying mails
  - auth: fixed crash with DIGEST-MD5 when attempting to do master user login
    without master passdbs
  - several fixes to mail_shared_explicit_inbox=no
  - imapc: use imapc_list_prefix also for listing subscriptions
- drop upstreamed systemd patch

* Wed May  9 2012 Paul Howarth <paul@city-fan.org> 1:2.1.6-2.0.cf
- fix socket activation again; fix in 2.1.6 is incomplete

* Tue May  8 2012 Paul Howarth <paul@city-fan.org> 1:2.1.6-1.0.cf
- dovecot updated to 2.1.6:
  - session ID is now included by default in auth and login process log lines;
    it can be added to mail processes also by adding %%{session} to
    mail_log_prefix
  - added ssl_require_crl setting, which specifies if CRL check must be
    successful when verifying client certificates
  - added mail_shared_explicit_inbox setting to specify if a shared INBOX
    should be accessible as "shared/$user" or "shared/$user/INBOX"
  - v2.1.5: using "~/" as mail_location or elsewhere failed to actually expand
    it to home directory
  - dbox: fixed potential assert-crash when reading dbox files
  - trash plugin: fixed behavior when quota is already over limit
  - mail_log plugin: logging "copy" event didn't work
  - proxying to backend server with SSL: verifying server certificate name
    always failed, because it was compared to an IP address
- drop systemd patch, now included in upstream release
- update SSLDIR patch

* Tue Apr 24 2012 Paul Howarth <paul@city-fan.org> 1:2.1.5-1.0.cf
- dovecot updated to 2.1.5:
  - IMAP: when neither the session nor the mailbox has modseq tracking enabled,
    return the mailbox as having NOMODSEQ in SELECT/EXAMINE reply (old versions
    in this situation always simply returned HIGHESTMODSEQ as 1, which could
    have broken some clients)
  - dict file: added optional fcntl/flock locking (default is dotlock)
  - fts-solr: doveadm fts rescan now resets indexes, which allows reindexing
    mails (this isn't a full rescan implementation like fts-lucene has)
  - doveadm expunge: added -d parameter to delete mailbox if it's empty after
    expunging
  - IMAP: several fixes related to mailbox listing in some configs
  - director: a lot of fixes and performance improvements
  - v2.1.4 didn't work without a mail home directory set
  - mbox: deleting a mailbox didn't delete its index files
  - pop3c: TOP command was sent incorrectly
  - trash plugin didn't work properly
  - LMTP: don't add a duplicate Return-Path: header when proxying
  - listescape: don't unescape namespace prefixes
- drop 2.1.4 post-release patch, now included in upstream release
- add patch to close systemd extra sockets that are not configured

* Tue Apr 10 2012 Paul Howarth <paul@city-fan.org> 1:2.1.4-1.1.cf
- add post-release fix for lib-storage

* Tue Apr 10 2012 Paul Howarth <paul@city-fan.org> 1:2.1.4-1.0.cf
- dovecot updated to 2.1.4:
  - added mail_temp_scan_interval setting and changed its default value from
    8 hours to 1 week
  - added pop3-migration plugin for easily doing a transparent IMAP+POP3
    migration to Dovecot: http://wiki2.dovecot.org/Migration/Dsync
  - doveadm user: added -m parameter to show some of the mail settings
  - proxying SSL connections crashed in v2.1.[23]
  - fts-solr: indexing mail bodies was broken
  - director: several changes to significantly improve error handling
  - doveadm import didn't import messages' flags
  - mail_full_filesystem_access=yes was broken
  - make sure IMAP clients can't create directories when accessing non-existent
    users' mailboxes via shared namespace
  - dovecot auth clients authenticating via TCP socket could have failed with
    bogus "PID already in use" errors
- package new pop3 migration plugin

* Mon Mar 19 2012 Paul Howarth <paul@city-fan.org> 1:2.1.3-1.0.cf
- dovecot updated to 2.1.3:
  - mdbox was broken in v2.1.2

* Fri Mar 16 2012 Paul Howarth <paul@city-fan.org> 1:2.1.2-1.0.cf
- dovecot updated to 2.1.2:
  - initial implementation of dsync-based replication; for now this should be
    used only on non-critical systems
  - proxying: POP3 now supports sending remote IP+port from proxy to backend
    server via Dovecot-specific XCLIENT extension
  - proxying: proxy_maybe=yes with host=<hostname> (instead of IP) now works
    properly
  - proxying: added auth_proxy_self setting
  - proxying: added proxy_always extra field (see wiki docs)
  - added director_username_hash setting to specify what part of the username
    is hashed; this can be used to implement per-domain backends (which allows
    safely accessing shared mailboxes within domain)
  - added a "session ID" string for imap/pop3 connections, available in
    %%{session} variable; the session ID passes through Dovecot IMAP/POP3
    proxying to backend server (the same session ID is can be reused after a
    long time, currently a little under 9 years)
  - passdb checkpassword: support "credentials lookups" (for non-plaintext
    auth and for lmtp_proxy lookups)
  - fts: added fts_index_timeout setting to abort search if indexing hasn't
    finished by then (default is to wait forever)
  - doveadm sync: if mailbox was expunged empty, messages may have come back
    instead of also being expunged in the other side
  - director: if user logged into two directors while near user expiration,
    the directors might have redirected the user to two different backends
  - imap_id_* settings were ignored before login
  - several fixes to mailbox_list_index=yes
  - previous v2.1.x didn't log all messages at shutdown
  - mbox: fixed accessing Dovecot v1.x mbox index files without errors
- package new replicator plugin and aggregator/replicator binaries
- drop support for distributions prior to FC-3:
  - unconditionally build with GSSAPI support
  - don't need to work around GNU ld not always having --as-needed
  - don't need to support systems with 2.4 kernels and no epoll

* Fri Mar  2 2012 Paul Howarth <paul@city-fan.org> 1:2.1.1-2.0.cf
- enable fts_lucene plugin for F-16 onwards (#798661)

* Thu Feb 23 2012 Paul Howarth <paul@city-fan.org> 1:2.1.1-1.0.cf
- dovecot updated to 2.1.1:
  - dsync: if message with same GUID is saved multiple times in session, copy
    it instead of re-saving
  - acl plugin + autocreated mailboxes crashed when listing mailboxes
  - doveadm force-resync: don't skip autocreated mailboxes (especially INBOX)
  - if process runs out of fds, stop listening for new connections only
    temporarily, not permanently (avoids hangs with process_limit=1 services)
  - auth: passdb imap crashed for non-login authentication (e.g. smtp)
- package new manpages for doveadm-instance and doveadm-mount
- add dependency on openssl for mkcert.sh

* Wed Feb 22 2012 Paul Howarth <paul@city-fan.org> 1:2.1.0-1.1.cf
- include pigeonhole doc files (NEWS, README, etc.)
- move libdovecot-ssl.so to devel package
- own directory /etc/pki/dovecot/ and its subdirectories
- systemd builds don't need chkconfig
- use absolute path for OPENSSLCONFIG in mkcert.sh

* Fri Feb 17 2012 Paul Howarth <paul@city-fan.org> 1:2.1.0-1.0.cf
- dovecot updated to 2.1.0:
  - added ignore_on_failure setting for namespaces: if namespace initialization
    fails with this enabled (e.g. permission denied), the namespace is silently
    skipped for the user
- pigeonhole updated to 0.3.0:
  - renamed sieve_global_path setting to sieve_default for clarity (old name
    is still recognized for backwards compatibility)
  - added means to prohibit use of redirect action: setting sieve_max_redirects
    to 0 now means that redirect is disallowed instead of unlimited
  - fixed interaction of Sieve include extension with ManageSieve: it is
    updated to match new requirements in the draft include specification, and
    missing included scripts are no longer an error at upload time
  - updated RFC2822 header field body verification to exclude non-printing
    characters (RFC5322)
  - completed sieve-filter tool to a useful state: the sieve-filter tool
    provides a means to (re)filter messages in a mailbox through a Sieve script
  - implemented the Sieve editheader extension: it is now possible to add and
    remove message headers from within Sieve
  - manageSieve: added support for reading quoted and literal strings as a
    stream, which fixes support for handing large SASL responses (analogous to
    similar changes in Dovecot)
  - added code to cleanup tmp directory in Sieve storage directory (sieve_dir)
    every once in a while
  - added support for substituting the entire message during Sieve processing:
    this is used for the filter action provided by the new sieve_extprograms
    plugin (provided separately for now) - the filter action allows passing the
    message through an external program
  - added support for restricting certain Sieve language extensions to
    (admin-controlled) global scripts: restricted extensions can be configured
    using the new sieve_global_extensions setting (this is particularly useful
    for some of the Dovecot-specific Sieve extensions, which can be somewhat
    hazardous when under direct control of users, e.g. sieve_extprograms)

* Tue Feb 14 2012 Paul Howarth <paul@city-fan.org> 1:2.1-0.7.0.rc6.cf
- dovecot updated to 2.1.rc6:
  - added automatic mountpoint tracking and doveadm mount commands to manage
    the list; if a mountpoint is unmounted, error handling is done by assuming
    that the files are only temporarily lost, which is especially helpful if
    dbox alt storage becomes unmounted
  - expire plugin: only go through users listed by userdb iteration; delete
    dict rows for nonexistent users, unless expire_keep_nonexistent_users=yes
  - LDA's out-of-quota and Sieve's reject mails now include DSN report instead
    of MDN report
  - LDAP: allow building passdb/userdb extra fields from multiple LDAP
    attributes by using %%{ldap:attributeName} variables in the template
  - doveadm log errors shows the last 1000 warnings and errors since Dovecot
    was started
  - improved multi-instance support: track automatically which instances are
    started up and manage the list with doveadm instance commands; all dovecot
    commands now support -i <instance_name> parameter to select the instance
    (instead of having to use -c <config path>)
  - doveadm mailbox delete: added -r parameter to delete recursively
  - doveadm acl: added "add" and "remove" commands
  - updated to Unicode v6.1
  - mdbox: when saving to alt storage, Dovecot didn't append as much data to
    m.* files as it could have
  - dbox: fixed error handling when saving failed or was aborted
  - IMAP: using COMPRESS extension may have caused assert-crashes
  - IMAP: THREAD REFS sometimes returned invalid (0) nodes
  - dsync: fixed handling non-ASCII characters in mailbox names
- update fallocate64 patch

* Thu Feb  9 2012 Paul Howarth <paul@city-fan.org> 1:2.1-0.6.0.rc5.cf
- dovecot updated to 2.1.rc5:
  - temporary authentication failures sent to IMAP/POP3 clients now include
    the server's hostname and timestamp, making it easier to find the error
    message from logs
  - auth: implemented support for Postfix's "TCP map" sockets for user
    existence lookups
  - director: with >2 directors, ring syncing might have stalled during
    director connect/disconnect, causing logins to fail
  - LMTP client/proxy: fixed potential hanging when sending (big) mails
  - compressed mails with external attachments (dbox + SIS + zlib) failed
    sometimes with bogus "cached message size wrong" errors
- pigeonhole updated to latest snapshot
- use private /tmp from Fedora 17

* Mon Jan  9 2012 Paul Howarth <paul@city-fan.org> 1:2.1-0.4.0.rc3.cf
- dovecot updated to 2.1.rc3:
  - dsync was merged into doveadm (there is still "dsync" symlink pointing to
    "doveadm", which you can use the old way for now); the preferred ways to
    run dsync are "doveadm sync" (for old "dsync mirror") and "doveadm backup"
  - IMAP SPECIAL-USE extension to describe mailboxes
  - added mailbox {} sections, which deprecate autocreate plugin
  - lib-fs: added "mode" parameter to "posix" backend to specify mode for
    created files/dirs (for mail_attachment_dir)
  - inet_listener names are now used to figure out what type the socket is
    when useful, e.g. naming service auth { inet_listener } to auth-client vs.
    auth-userdb has different behaviour
  - added pop3c (= POP3 client) storage backend
  - LMTP proxying code was simplified, hopefully fixing its problems
  - dsync: don't remove user's subscriptions for subscriptions=no namespaces

* Wed Dec 14 2011 Paul Howarth <paul@city-fan.org> 1:2.1-0.3.0.rc1.cf
- allow imap+TLS and pop3+TLS by default

* Thu Dec  1 2011 Paul Howarth <paul@city-fan.org> 1:2.1-0.2.0.rc1.cf
- only do systemctl daemon-reload in %%postun for systemd-based distros

* Wed Nov 30 2011 Paul Howarth <paul@city-fan.org> 1:2.1-0.1.0.rc1.cf
- dovecot updated to 2.1.rc1:
  - plugins now use UTF-8 mailbox names rather than mUTF-7
  - auth_username_format default changed to %%Lu
  - solr full text search backend changed to use mailbox GUIDs instead of
    mailbox names, requiring reindexing everything
- reinstate code for fixing up pigeonhole snapshots
- update fallocate64() patch
- do systemctl daemon-reload in %%postun to update systemd on upgrade
- patch out use of --as-needed linker option on old distributions where it's
  not supported

* Thu Nov 17 2011 Paul Howarth <paul@city-fan.org> 1:2.0.16-1.0.cf
- dovecot updated to 2.0.16:
  - VSZ limits weren't being enforced for any processes; on a server with large
    mailboxes you may now see errors about it if the limits aren't high enough
  - proxying: if using ssl=yes or starttls=yes with a hostname (not IP) as
    proxy destination, require that the certificate matches the given hostname
  - LMTP: changed default client_limit to 1, which should improve LMTP
    throughput with default settings
  - dsync: quota is no longer enforced (i.e. dsync can't fail because user is
    over quota)
  - added "auto" mail storage driver, which can be used to autodetect mailbox
    location and format
  - checkpassword: export all auth %%variables to AUTH_* environment
- package manpage for doveadm-move(1)

* Sat Oct 29 2011 Paul Howarth <paul@city-fan.org> 1:2.0.15-2.0.cf
- do not use obsolete settings in default configuration (#743444)

* Mon Sep 19 2011 Paul Howarth <paul@city-fan.org> 1:2.0.15-1.0.cf
- dovecot updated to 2.0.15:
  - doveadm altmove: added -r parameter to move mails back to primary storage
  - v2.0.14: index reading could have eaten a lot of memory in some situations
  - doveadm index no longer affects future caching decisions
  - mbox: fixed crash during mail delivery when mailbox didn't yet have GUID
    assigned to it
  - zlib+mbox: fetching last message from compressed mailboxes crashed
  - lib-sql: fixed load balancing and error handling when multiple hosts are
    used

* Tue Sep 13 2011 Paul Howarth <paul@city-fan.org> 1:2.0.14-2.0.cf
- do not enable insecure connections by default

* Mon Sep  5 2011 Paul Howarth <paul@city-fan.org> 1:2.0.14-1.0.cf
- dovecot updated to 2.0.14:
  - doveadm: added support for running mail commands by proxying to another
    doveadm server
  - added "doveadm proxy list" and "doveadm proxy kick" commands to list/kick
    proxy connections (via a new "ipc" service)
  - added "doveadm director move" to assign user from one server to another,
    killing any existing connections
  - added "doveadm director ring status" command
  - userdb extra fields can now return name+=value to append to an existing
    name, e.g. "mail_plugins+= quota"
  - script-login attempted an unnecessary config lookup, which usually failed
    with "Permission denied"
  - lmtp: fixed parsing quoted strings with spaces as local-part for
    MAIL FROM and RCPT TO
  - imap: FETCH BODY[HEADER.FIELDS (..)] may have crashed or not returned all
    data sometimes
  - ldap: fixed random assert-crashing with with sasl_bind=yes
  - fixes to handling mail chroots
  - fixed renaming mailboxes under different parent with FS layout when using
    separate ALT, INDEX or CONTROL paths
  - zlib: fixed reading concatenated .gz files
- update fallocate64() patch
- package %%{_libexecdir}/dovecot/ipc

* Fri May 27 2011 Paul Howarth <paul@city-fan.org> 1:2.0.13-2.0.cf
- don't include the SysV initscript for systemd-using distributions

* Thu May 12 2011 Paul Howarth <paul@city-fan.org> 1:2.0.13-1.0.cf
- dovecot updated to 2.0.13:
  - added "doveadm index" command to add unindexed messages into index/cache;
    if full text search is enabled, it also adds unindexed messages to the fts
    database
  - added "doveadm director dump" command
  - pop3: added support for showing messages in "POP3 order", which can be
    different from IMAP message order; this can be useful for migrations from
    other servers
  - doveconf: fixed a wrong "subsection has ssl=yes" warning
  - mdbox purge: fixed wrong warning about corrupted extrefs
  - sdbox: INBOX GUID changed when INBOX was autocreated, leading to trouble
    with dsync
  - script-login binary wasn't actually dropping privileges to the
    user/group/chroot specified by its service settings
  - fixed potential crashes and other problems when parsing header names that
    contained NUL characters
- add manpage doveadm-index(1)

* Fri Apr 15 2011 Paul Howarth <paul@city-fan.org> 1:2.0.12-2.0.cf
- pigeonhole updated to 0.2.3:
  - managesieve: fixed bug in UTF-8 checking of string values
  - sieve command line tools now avoid initializing the mail store unless
    necessary
  - removed header MIME-decoding to fix erroneous address parsing
  - fixed segfault in extension configuration, triggered when unknown
    extension is mentioned in sieve_extensions setting

* Wed Apr 13 2011 Paul Howarth <paul@city-fan.org> 1:2.0.12-1.0.cf
- dovecot updated to 2.0.12:
  - doveadm: added "move" command for moving mails between mailboxes
  - virtual: added support for "+mailbox" entries that clear \Recent flag from
    messages (default is to preserve them)
  - dbox: fixes to handling of external attachments
  - dsync: more fixes to avoid hanging with remote syncs
  - dsync: many other syncing/correctness fixes
  - doveconf: v2.0.10 and v2.0.11 didn't output plugin {} section right
- drop upstreamed patch for config file parsing (#690401)
- nobody else likes macros for commands

* Mon Mar 28 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-5.0.cf
- fix regression in config file parsing (#690401)

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-3.0.cf
- resync with Rawhide (sigh)

* Wed Mar 23 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-2.0.cf
- rebuild for new MySQL client library in Rawhide

* Sun Mar  6 2011 Paul Howarth <paul@city-fan.org> 1:2.0.11-1.0.cf
- dovecot updated to 2.0.11:
  - dotlock_use_excl setting's default was accidentally "no" in all v2.0.x
    releases, instead of "yes" as in v1.1 and v1.2; changed it back to "yes"
  - v2.0.10: LDAP support was broken
  - v2.0.10: dsyncing to remote often hanged (timed out in 15 mins)
- drop upstream LDAP auth crash patch

* Sat Mar  5 2011 Paul Howarth <paul@city-fan.org> 1:2.0.10-2.0.cf
- add upstream fix for LDAP auth crash

* Sat Mar  5 2011 Paul Howarth <paul@city-fan.org> 1:2.0.10-1.0.cf
- dovecot updated to 2.0.10:
  - LMTP: For user+detail@domain deliveries, the +detail is again written to
    Delivered-To: header
  - Skip auth penalty checks from IPs in login_trusted_networks
  - Added import_environment setting
  - Added submission_host setting to send mails via SMTP instead of via
    sendmail binary
  - Added doveadm acl get/set/delete commands for ACL manipulation, similar to
    how IMAP ACL extension works
  - Added doveadm acl debug command to help debug and fix problems with why
    shared mailboxes aren't working as expected
  - IMAP: Fixed hangs with COMPRESS extension
  - IMAP: Fixed a hang when trying to COPY to a non-existent mailbox
  - IMAP: Fixed hang/crash with SEARCHRES + pipelining $
  - IMAP: Fixed assert-crash if IDLE+DONE is sent in same TCP packet
  - LMTP: Fixed sending multiple messages in a session
  - doveadm: Fixed giving parameters to mail commands
  - doveadm import: Settings weren't correctly used for the import storage
  - dsync: Fixed somewhat random failures with saving messages to remote dsync
  - v2.0.9: Config reload didn't notify running processes with
    shutdown_clients=no, so they could have kept serving new clients with old
    settings
- drop upstreamed systemd patch

* Thu Feb 17 2011 Paul Howarth <paul@city-fan.org> 1:2.0.9-3.0.cf
- add missing section to dovecot's systemd service file

* Tue Feb  8 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> 1:2.0.9-2.0.cf
- rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Jan 13 2011 Paul Howarth <paul@city-fan.org> 1:2.0.9-1.0.cf
- dovecot updated to 2.0.9:
  - Fix a high system CPU usage/high context switch count performance problem
  - lda: Fix a crash when trying to send "out of quota" reply

* Mon Dec 20 2010 Paul Howarth <paul@city-fan.org> 1:2.0.8-3.0.cf
- resync with rawhide

* Tue Dec  7 2010 Paul Howarth <paul@city-fan.org> 1:2.0.8-2.0.cf
- pigeonhole updated to 0.2.2
- use systemd activation from Fedora 15 onwards

* Mon Dec  6 2010 Paul Howarth <paul@city-fan.org> 1:2.0.8-1.0.cf
- dovecot updated to 2.0.8:
  - Services' default vsz_limits weren't being enforced correctly in earlier
    v2.0 releases. Now that they are enforced, you might notice that the
    default limits are too low and you need to increase them. This problem
    will show up in logs as "out of memory" errors. See default_vsz_limit and
    service { vsz_limit } settings.
  - LMTP: In earlier versions if mail was delivered to user+detail@domain
    address, LMTP server always attempted to deliver the mail to mailbox named
    "detail". This was rather unintentional and shouldn't have been the
    default. lmtp_save_to_detail_mailbox=yes setting now preserves this
    behavior (default is no).
  - Added systemd support (configure --with-systemdsystemunitdir).
  - Replaced broken mbox-snarf plugin with a new more generic snarf plugin.
  - dbox: Fixes to handling external mail attachments
  - verbose_proctitle=yes didn't work for all processes in v2.0.7
  - imap, pop3: When service { client_count } was larger than 1, the log
    messages didn't use the correct prefix. Last logged in user's prefix was
    always used, regardless of what user's session actually logged it. Now the
    proper log prefix is always used.
  - MySQL: Only the first specified host was ever used
- lib20_mbox_snarf_plugin replaced by lib05_snarf_plugin.so

* Mon Nov 29 2010 Paul Howarth <paul@city-fan.org> 1:2.0.7-3.0.cf
- make it work with /var/run on tmpfs (#656577)

* Tue Nov 23 2010 Paul Howarth <paul@city-fan.org> 1:2.0.7-2.0.cf
- fix regression with valid_chroot_dirs being ignored (#654083)

* Tue Nov  9 2010 Paul Howarth <paul@city-fan.org> 1:2.0.7-1.0.cf
- dovecot updated to 2.0.7:
  - IMAP: fixed LIST-STATUS for subscriptions with subscriptions=no namespaces
  - IMAP: fixed SELECT QRESYNC not to crash on mailbox close
  - quota: don't count virtual mailboxes in quota
  - doveadm expunge didn't always actually do the physical expunging
  - fixed some index reading optimizations introduced by v2.0.5
  - LMTP proxying fixes
- pigeonhole updated to current snapshot

* Fri Oct 22 2010 Paul Howarth <paul@city-fan.org> 1:2.0.6-1.0.cf
- dovecot updated to 2.0.6:
  - pre-login CAPABILITY includes IDLE again
  - auth: auth_cache_negative_ttl default restored from 0 to 1h as per 1.x
  - dbox: added initial support for saving mail attachments to external files
  - doveadm: added import command for importing mails from other storages
  - reduced NFS I/O operations for index file accesses
  - dbox, Maildir: when copying messages, copy also already cached index fields
  - mdbox: added mdbox_preallocate_space setting (Linux+ext3/XFS only)
  - Maildir: LDA/LMTP assert-crashed sometimes when saving a mail
  - fixed leaking fds when writing to dovecot.mailbox.log
  - fixed rare dovecot.index.cache corruption
  - IMAP: SEARCH YOUNGER/OLDER wasn't working correctly
- pigeonhole updated to current snapshot
- add patch to work around broken fallocate with glibc 2.10 32-bit (#500487)

* Mon Oct  4 2010 Paul Howarth <paul@city-fan.org> 1:2.0.5-1.0.cf
- dovecot updated to 2.0.5:
  - acl: fix the logic of merging multiple ACL entries
  - virtual: allow opening virtual mailboxes referring to non-existing mailboxes
  - add some disk I/O optimizations to Maildir and index code
  - pop3: add pop3_fast_size_lookups setting
  - doveconf sometimes failed with complaining about missing ssl_key setting
  - lda: dovecot exits with EX_TEMPFAIL if there's an error in configuration
  - sdbox: fix memory leak when copying messages with hard links
  - zlib + sdbox combination didn't work
  - zlib: fixed several crashes, which mainly showed up with mbox
  - quota: don't crash if user has quota disabled, but plugin loaded
  - doveadm fetch uid was actually returning sequence, not uid
  - v2.0.4's subscription listing could ignore 'subscriptions=no namespaces'
  - acl: fix crashing when sometimes listing shared mailboxes via dict proxy
- pigeonhole updated to current snapshot

* Thu Sep 30 2010 Paul Howarth <paul@city-fan.org> 1:2.0.4-2.0.cf
- rebuild for gcc bug (#634757)

* Tue Sep 28 2010 Paul Howarth <paul@city-fan.org> 1:2.0.4-1.1.cf
- pigeonhole updated to 0.2.1 snapshot

* Mon Sep 27 2010 Paul Howarth <paul@city-fan.org> 1:2.0.4-1.0.cf
- dovecot updated to 2.0.4:
  - multi-dbox: honour :INDEX=path more completely
  - Maildir: fix copying with hard links
  - Maildir: v2.0.3 broke expunging copied messages sometimes
  - Maildir: INBOX whose tmp/ directory was lost couldn't be opened
  - single-dbox: messages weren't copied with hard links
  - vpopmail support is hopefully working again
  - dsync: POP3 UIDLs weren't copied with Maildir
  - dict file: fixed fd leak (showed up easily with LMTP + quota)

* Mon Sep 20 2010 Paul Howarth <paul@city-fan.org> 1:2.0.3-1.0.cf
- dovecot updated to 2.0.3; pigeonhole updated to today's snapshot
  - dovecot-lda: removed use of non-standard Envelope-To: header as a default
    for -a (set lda_original_recipient_header=Envelope-To to return to the old
    behaviour)
  - added support for reverse quota warnings (i.e. when quota goes back under
    the limit), enabled by adding '-' to beginning of quota_warning value
  - dovecot-lda: added lda_original_recipient_header setting, which is used for
    getting original recipient if -a isn't used
  - dovecot-lda: added -r parameter to specify final recipient address, which
    may differ from the original address due to e.g. aliases
  - Maildir: uidlist file can now override message's GUID, making it possible
    for multiple messages in a mailbox to have the same GUID (this also fixes
    dsync's message conflict resolution)
  - dovecot-lda: if destination user isn't found, exit with EX_NOUSER, not
    EX_TEMPFAIL
  - dsync: fixed handling \Noselect mailboxes
  - fixed an infinite loop introduced by v2.0.2's message parser changes
  - fixed a crash introduced by v2.0.2's istream-crlf changes

* Thu Sep 16 2010 Paul Howarth <paul@city-fan.org> 1:2.0.2-1.1.cf
- pigeonhole updated (now 0.2.0 rather than 0.2.UNSTABLE)
- dropped redundant patch for pigeonhole build from cooked tarball

* Thu Sep  9 2010 Paul Howarth <paul@city-fan.org> 1:2.0.2-1.0.cf
- dovecot updated to 2.0.2
  - vpopmail support is disabled for now, since it's broken
  - maildir: fixed "duplicate uidlist entry" errors
  - deleting ACLs didn't cause entries to be removed from acl_shared_dict
  - mail_max_lock_timeout setting wasn't working with all locks
  - auth_cache_size setting's old-style value wasn't autoconverted properly

* Wed Aug 25 2010 Paul Howarth <paul@city-fan.org> 1:2.0.1-1.0.cf
- dovecot updated to 2.0.1
  - dsync doesn't drop privileges when started as root
  - imap: QRESYNC parameters for SELECT weren't handled correctly
  - UTF-8 string validity checking wasn't done correctly
  - dsync: fixed a random assert-crash with remote dsyncing
- pigeonhole updated
  - sieved renamed to sieve-dump
  - ship manpage for pigeonhole(7)
- add patch to fix pigeonhole build from cooked tarball

* Wed Aug 18 2010 Paul Howarth <paul@city-fan.org> 1:2.0.0-1.1.cf
- pigeonhole updated

* Tue Aug 17 2010 Paul Howarth <paul@city-fan.org> 1:2.0.0-1.0.cf
- dovecot 2.0.0 release
  - dict quota didn't always decrease quota when messages were expunged
  - shared INBOX wasn't always listed with FS layout
- drop kludges for nightly builds

* Wed Aug 11 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.21.0.rc5.cf
- dovecot and pigeonhole updated
  - using more than 2 plugins could have caused broken behavior
  - listescape plugin fixes
  - mbox: fixed a couple of assert-crashes
  - mdbox: fixed potential assert-crash when saving multiple messages 

* Thu Aug  5 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.20.0.rc4.cf
- dovecot updated to 2.0.rc4, pigeonhole to 20100805 build
  - doveadm mailbox status: fixed listing non-ASCII mailbox names
  - doveadm fetch: fixed output when fetching message header or body
  - doveadm director map/add/remove: fixed handling IP address as parameter
  - dsync: a few more fixes
- package doveadm-server

* Wed Jul 21 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.19.0.rc3.cf
- dovecot updated to 2.0.rc3, pigeonhole to 20100721 build
  - fixed lda + sieve crash
  - added mail_temp_dir setting; default is /tmp
  - imap: fixed checking if list=children namespace has children
  - mdbox: race condition fixes related to copying and purging
- completely remove betahotfix patch
- pigeonhole test suite now uses "make check" rather than "make test"

* Mon Jul 19 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.18.1.rc1.20100716.cf
- dovecot and pigeonhole updated to 20100716 build
  - acl: fixed crash on FS layout with non-default hierarchy separator
  - dbox renamed to sdbox
  - dsync fixes and improvements
  - fixed a crash with empty mail_plugins
  - fixed sharing INBOX to other users
  - director+LMTP proxy wasn't working correctly
  - v1.x config parser failed with some settings if pigeonhole wasn't installed
  - virtual: fix expunging of non-matching messages
- enabled pigeonhole's build time test suite
- drop betahotfix patch again
- don't try to use Linux 2.6 epoll for targets that use Linux 2.4 kernels

* Wed Jul  7 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.16.1.rc1.20100707.cf
- updated dovecot and pigeonhole to 20100707 build
- update betahotfix patch
- package new manpage for doveadm-config(1)

* Tue Jun 29 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.16.0.rc1.cf
- updated dovecot to 2.0.rc1
 - added man pages, mostly written by Pascal Volk
 - dsync syntax changed, although it's still compatible with old syntax
 - dsync backup command added
 - dsync should now be stable
 - LMTP proxying supports director
 - director should now be stable
 - single-dbox should now be stable
 - mdbox locking behavior modified to avoid deadlocks
 - fsync_disable=no was renamed to mail_fsync = optimized (default)
 - fsync_disable=yes was renamed to mail_fsync = never
 - added a new mail_fsync = always
- manpages now integrated into main dovecot tarball
- no longer need to recode auth-protocol.txt as UTF-8

* Mon Jun 28 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.15.0.beta6.20100626.cf
- updated dovecot, pigeonhole and man pages to 20100626 build
  - moved disable_plaintext_auth to 10-auth.conf
  - mdbox: fixed assert-crash on storage rebuild if file got lost
  - lib-charset: don't assert-crash when iconv() skips lots of invalid input
  - master: fixed crash on deinit (maybe also on reload)

* Thu Jun 10 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.14.0.beta5.20100610.cf
- dovecot updated to 20100610 build
  - lib-storage: fixed accessing uncommitted saved mails with dsync
  - example-config: moved ACL and quota settings to a separate .conf files
  - dbox, mdbox: fixed race conditions when creating mailboxes
- package %%{_libexecdir}/dovecot/script-login

* Tue Jun  1 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.13.0.beta5.20100529.cf
- dovecot and pigeonhole updated
  - master: fixed crash on config reload
  - lib-storage: don't assert-crash when copying a mail fails
- enable Solr fulltext search where possible
- buildreq libcurl-devel and expat-devel for Solr support
- package %%{_libexecdir}/dovecot/director
- package %%{_libdir}/dovecot/doveadm/lib10_doveadm_expire_plugin.so
- move %%{_libdir}/dovecot/doveadm/lib10_doveadm_quota_plugin.so to main package
- %%{_libexecdir}/dovecot/expire-tool no longer included
- use -fno-strict-aliasing

* Tue May 18 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.12.0.beta5.20100515.cf
- pigeonhole and dovecot updated to snapshot 20100515
  - fixed crash for THREAD command
  - removed imap-utf7 binary (doveadm mailbox convert replaced it)
- create dovenull user account for login process

* Wed May 12 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.9.0.beta5.20100512.cf
- pigeonhole and dovecot updated to snapshot 20100512
- betahotfix patch upstreamed
- fix dist tag for RHEL-6 Beta
- script-ify procedure for fixing up the pigeonhole snapshot tarball

* Wed May  5 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.8.0.beta4.20100505.cf
- pigeonhole and dovecot updated to snapshot 20100505
  - mdbox: avoid rebuilding storage if another process already did it
  - lib-storage: fixed () sublists in IMAP SEARCH parser
  - example-config: auth-checkpassword include wasn't listed in 10-auth.conf
  - doveadm: added search command
  - lib-master: don't crash after timing out an auth-master request
  - master: inet listener listens on all addresses from a DNS name
- update snapshot fixups patch

* Wed Apr 28 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.7.0.beta4.20100427.cf
- updated to snapshot 20100427
  - doveconf <setting name> now prints only the one setting's value
  - mdbox: automatically delete old temp.* files from storage/ directory
  - mdbox: use flock locking by default

* Thu Apr 22 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.6.0.beta4.20100421.cf
- updated to snapshot 20100421
  - mdbox: purge crashed if it purged all messages from a file
  - lib-storage: shared namespace's prefix_len updated after prefix truncated
  - imap-quota: iterate quota roots only once when replying to GETQUOTAROOT
  - idle: do cork/uncork when sending "OK Still here" notification
  - login: if proxy returns ssl=yes and no port, switch port to imaps/pop3s
- new managesieve patch for dovecot API change

* Wed Apr 14 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.5.0.beta4.20100414.cf
- dovecot updated to snapshot 20100414
  - config: add nn- prefix to *.conf files so sort ordering makes more sense
  - lib-master: log an error if login client disconnects too early
  - mdbox: if purging finds corrupted files, auto-rebuild storage
  - lib-storage: add support for searching save date
  - and more...
- pigeonhole updated to snapshot ece958a18920
  - mailbox extension: fix memory leak in the mailboxexists test
  - add login failure handler
- add make check
- tweak %%configure options
- fix patches for renamed files
- re-enable default-settings patch
- managesieve patch for dovecot API change no longer needed

* Tue Apr  6 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.4.0.beta4.20100406.cf
- updated to 20100406 nightly build
  - auth: if userdb lookup fails internally, don't cache the result
  - added support for userdb lookup to fail with a reason
  - sdbox: mailbox_update() could have changed UIDVALIDITY incorrectly
  - layout=maildir++: fixed deleting mailboxes with mailbox=file storages
  - fixed potential problems with parsing invalid address groups
  - dsync: don't repeatedly try to keep opening the same failing mailbox
  - lib-storage: don't crash if root mail directory isn't given
- fix managesieve for API change in dovecot

* Thu Apr  1 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.3.0.beta4.20100330.cf
- update to 20100330 nightly build
- drop snapshot patch, no longer needed
- work around absence of --docdir option in configure scripts generated using
  autoconf 2.59 as in the nightly builds

* Tue Mar 30 2010 Paul Howarth <paul@city-fan.org> 1:2.0-0.2.0.beta4.cf
- update to 2.0.beta4
- drop documentation relating to migration from UW-IMAP
- leave DH parameter generation to dovecot
- bump epoch of sieve and managesieve provides as their version number has
  gone backwards to 0.1.13

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-3.0.cf
- drop mbox bzip support as it's broken and upstream does not plan to fix it in
  dovecot 1.2 (http://www.dovecot.org/list/dovecot/2010-February/046789.html)
- use managesieve patch for dovecot 1.2.11

* Fri Mar 12 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-2.0.cf
- rebuild: Fedora version didn't have bzip2 support (#572797)

* Tue Mar  9 2010 Paul Howarth <paul@city-fan.org> 1:1.2.11-1.0.cf
- updated dovecot to 1.2.11
  - mbox: message header reading was unnecessarily slow and CPU-intensive
  - mbox, dbox, cydir: fix mail root directory permissions
  - maildir: reading uidlist could have ended up in an infinite loop
  - IMAP IDLE: v1.2.7+ caused extra load by checking changes too often

* Wed Feb 24 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-4.0.cf
- merged dovecot-sieve and dovecot-managesieve into dovecot-pigeonhole
- merged dovecot-sqlite, dovecot-gssapi and dovecot-ldap into dovecot

* Thu Jan 28 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-2.0.cf
- rebuild

* Mon Jan 25 2010 Paul Howarth <paul@city-fan.org> 1:1.2.10-1.0.cf
- dovecot updated to 1.2.10
  - %%variables now support %%{host}, %%{pid} and %%{env:VAR_NAME} everywhere
  - LIST-STATUS capability is now advertised
  - maildir: Fixed several assert-crashes.
  - imap: LIST "" inbox shouldn't crash if using namespace with "INBOX." prefix
  - lazy_expunge now ignores non-private namespaces
- sieve updated to 0.1.15
  - enotify: adjusted notify method API for addition of new methods
  - enotify: set default importance level to 'normal' (was 'high')
  - include: updated implementation towards most recent specification
  - envelope path parser allows addresses that have no domain part
  - preliminary support for Sieve plugins
  - support for installing Sieve development headers
  - deprecated notify extension: implemented denotify command
  - variables extension: added support for variable namespaces
  - added configurable script size limit
  - testsuite enhancements
  - fixed a bug in the i;ascii-numeric comparator (see NEWS)
  - imap4flags: fixed bug in removeflag (see NEWS)
  - improved some error messages
  - fixed typo in runtime log message for vacation extension
  - fixed parser recovery
- managesieve updated to 0.11.11
  - adjustments to match changes in the Sieve API
  - implement ManageSieve QUOTA enforcement
  - added MAXREDIRECTS capability after login
  - implement ew script name rules specified in most recent ManageSieve draft
  - fix assertion failure occuring with challenge-response SASL mechanisms

* Tue Dec 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.9-2.0.cf
- dovecot updated to 1.2.9
  - maildir: when saving, filenames now always contain ,S=<size>
  - maildir: fix assert-crashes in v1.2.7 and v1.2.8
  - maildir_copy_preserve_filename=yes could have caused crashes
  - maildir++ quota: update %% limits from maildirsize
  - virtual: v1.2.8 didn't fully fix the "lots of mailboxes" bug
  - virtual: fixed updating virtual mailbox based on flag changes
  - fts-squat: fixed searching multi-byte characters
- sieve updated to 0.1.14
  - limits of redirects and actions now configurable
  - extension handling no longer needs to maintain global state
  - made LDA Sieve plugin recognize the deliver_log_format setting
  - outgoing message headers now RFC2047-encoded
  - add support for the $text$ substitution in the deprecated notify extension
  - recipient_delimiter is now an alias for sieve_subaddress_sep
  - fixed logging of mailbox names (uses UTF8)
  - fix a minor memory leak in the multiscript support
  - fix a bug in the recompilation of Sieve scripts (only done when needed)
- managesieve updated to 0.11.10
  - adjustments to match changes in the Pigeonhole Sieve API (requires 0.1.14)
  - fix compilation of ManageSieve against CMUSieve

* Wed Nov 25 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-4.0.cf
- fix dovecot's restart after update (#518753)

* Tue Nov 24 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-2.0.cf
- use managesieve patch for dovecot 1.2.8

* Fri Nov 20 2009 Paul Howarth <paul@city-fan.org> 1:1.2.8-1.0.cf
- dovecot updated to 1.2.8
  - fix base_dir's permissions from 0777 to 0755 (see NEWS)
  - merge acls from multiple groups
  - virtual: fix OOM when using a lot of mailboxes
  - return RFC 2231 "key*" fields correctly in FETCH BODYSTRUCTURE

* Mon Nov 16 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-3.0.cf
- use upstream managesieve patch for dovecot 1.2.7
- rawhide dist tag no longer needs special-casing

* Fri Nov 13 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-2.0.cf
- add default config copy in %%{docdir}
- add manpages for dovecot(8), dovecot.conf(5), dovecotpw(1)

* Tue Nov 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.7-1.0.cf
- dovecot updated to 1.2.7
  - imap: send "still here" notifications for user's connections simultaneously
  - imap: if imap_capability is set, show it in the login banner
  - imap: implemented SORT=DISPLAY extension
  - login: fix process creation epoll_ctl() errors
  - maildir: fix some performance issues
  - maildir: fix crash when using a lot of keywords
  - several fixes to QRESYNC extension and modseq handling
  - mbox: make sure failed saves get rolled back with NFS
  - dbox: several fixes
- update managesieve patch locally to apply against dovecot 1.2.7
- drop upstreamed imap_capability patch
- drop SSL compression patch; issue resolved upstream

* Mon Nov  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-5.0.cf
- minor spec clean-up

* Thu Oct 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-4.0.cf
- imap-login: if imap_capability is set, show it in the banner instead of the
  default (#524485)

* Thu Oct 22 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-3.0.cf
- fix initscript for case when no action was specified

* Mon Oct 19 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-1.1.cf
- sieve updated to 0.1.13
  - body extension: proper handling of the :raw transform
  - body extension: added various new tests to the test suite
  - body extension: don't give SKIP_BODY_BLOCK flag to message parser
  - fix race condition when multiple instances are saving the same binary
  - multiscript: subsequent keep actions merged correctly
  - multiscript: implicit side effects handled correctly
  - sieve-test: fix segfault when compile fails
  - fix segfault in action processing when merging side effects
  - fix sieve plugin to not stat() a NULL path, yielding a 'Bad address' error

* Tue Oct  6 2009 Paul Howarth <paul@city-fan.org> 1:1.2.6-1.0.cf
- dovecot updated to 1.2.6
  - added authtest utility for doing passdb and userdb lookups
  - login: ssl_security string now also shows the used compression
  - quota: Don't crash with non-Maildir++ quota backend
  - imap proxy: Fixed crashing with some specific password characters
  - dovecot --exec-mail was broken
  - avoid assert-crashing when two processes try to create index simultaneously
- update managesieve patch to 1.2.6 version
- add patch to revert ssl_proxy_get_security_string() to the dovecot-1.2.5
  version if we have openssl < 0.9.8, which does not have the required
  functions SSL_COMP_get_name and SSL_get_current_compression

* Wed Sep 30 2009 Paul Howarth <paul@city-fan.org> 1:1.2.5-2.0.cf
- use password-auth common PAM configuration instead of system-auth
- use %%{_initddir} rather than %%{_initrddir}
- add some UID=0 checks in the initscript

* Mon Sep 14 2009 Paul Howarth <paul@city-fan.org> 1:1.2.5-1.0.cf
- dovecot updated to 1.2.5
- authentication: DIGEST-MD5 and RPA mechanisms no longer require
  user's login realm to be listed in auth_realms; it only made
  configuration more difficult without really providing extra security
- zlib plugin: don't allow clients to save compressed data directly;
  this prevents users from exploiting (most of the) potential security
  holes in zlib/bzlib
- fix index file handling that could have caused an assert-crash
- IMAP: fixes to QRESYNC extension
- deliver: don't send rejects to any messages that have Auto-Submitted
  header; this avoids emails loops

* Mon Aug 31 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-2.0.cf
- rebuild for openssl 1.0 in Rawhide

* Fri Aug 21 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-1.1.cf
- sieve updated to 0.1.12
- managesieve updated to 0.11.9
- drop dovecot-1.2.4-managesieve-0.11.8 patch, no longer needed

* Tue Aug 18 2009 Paul Howarth <paul@city-fan.org> 1:1.2.4-1.0.cf
- dovecot updated to 1.2.4
- sieve updated to 0.1.11
- add http://pigeonhole.dovecot.org/ URL for sieve and managesieve packages
- add manpage for sieve-filter
- add patch to fix managesieve build against dovecot-1.2.4

* Mon Aug 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.3-1.0.cf
- dovecot updated to 1.2.3
- managesieve updated to 0.11.8
- drop GSSAPI patch, in upstream release

* Thu Jul 30 2009 Paul Howarth <paul@city-fan.org> 1:1.2.2-2.0.cf
- apply fix from 20090728 post-release snapshot to fix GSSAPI (#506782)
- merge default-settings patch from Fedora
- add --with-unfinished-features to sieve %%configure to build sieve-filter

* Tue Jul 28 2009 Paul Howarth <paul@city-fan.org> 1:1.2.2-1.0.cf
- dovecot updated to 1.2.2
- managesieve updated to 0.11.7
- drop managesieve SASL patch, no longer needed
- sieve plugin changed from CMU to Dovecot Sieve (0.1.9, epoch bumped to 2)
- license for sieve subpackage now just LGPL v2.1 or later

* Fri Jul 10 2009 Paul Howarth <paul@city-fan.org> 1:1.2.1-1.0.cf
- dovecot updated to 1.2.1
- managesieve updated to 0.11.6
- remove managesieve timeout patch, now upstream
- add patch to managesieve for SASL changes in 1.2.1

* Thu Jul  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2.0-1.0.cf
- dovecot updated to 1.2.0

* Wed Jul  1 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.6.0.rc8.cf
- dovecot updated to 1.2.rc8
- remove upstreamed ldap-plugin patch
- remove autotools patch - we're not changing any autotools input files

* Mon Jun 29 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.5.0.rc7.cf
- dovecot updated to 1.2.rc7
- autotools patch rebuilt
- add buildreq libcap-devel for capabilities-dropping support
- add patch to fix configure script for LDAP auth plugin

* Thu Jun 25 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.4.0.rc6.cf
- dovecot updated to 1.2.rc6
- add patch for timeout sanity check in managesieve that needed inverting
- imap_utf7 renamed to imap-utf7

* Wed Jun 24 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.3.0.rc5.cf
- dovecot updated to 1.2.rc5
- managesieve updated to 0.11.5
- dovecot-1.2-ldap.patch dropped
- dovecot-1.2-default-settings.patch updated from Fedora's
  dovecot-1.1-default-settings.patch
- autotools patch rebuilt
- re-enable parallel make

* Thu Apr  2 2009 Paul Howarth <paul@city-fan.org> 1:1.2-0.2.0.beta4.cf
- dovecot updated to 1.2.beta4
- managesieve updated to 0.11.3
- dovecot-1.2-ldap.patch added from Fedora
- dovecot-1.1-default-settings.patch updated from Fedora and properly named as
  dovecot-1.2-default-settings.patch
- autotools patch rebuilt
- update login-dir patch
- Fedora 9 onwards clear out /var/run in a different way to older releases;
  bear this in mind when deciding whether to move the login-dir
- make PAM configuration %%config(noreplace)
- disable parallel make (build failure on rhel3.64)

* Fri Mar 20 2009 Paul Howarth <paul@city-fan.org> 1:1.1.13-1.0.cf
- dovecot updated to 1.1.13
- update autotools patch

* Sat Mar 14 2009 Paul Howarth <paul@city-fan.org> 1:1.1.12-1.0.cf
- dovecot updated to 1.1.12
- update autotools patch

* Mon Mar  2 2009 Paul Howarth <paul@city-fan.org> 1:1.1.11-2.0.cf
- rebuild for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Wed Feb  4 2009 Paul Howarth <paul@city-fan.org> 1:1.1.11-1.0.CF
- dovecot updated to 1.1.11
- update managesieve to 0.10.5
- update autotools patch

* Tue Jan 27 2009 Paul Howarth <paul@city-fan.org> 1:1.1.10-1.0.CF
- dovecot updated to 1.1.10
- locally update managesieve patch
- update autotools patch

* Mon Jan 26 2009 Paul Howarth <paul@city-fan.org> 1:1.1.9-1.0.CF
- dovecot updated to 1.1.9
- locally update managesieve patch
- update autotools patch
- inotify and docs support enabled by default, drop configure options

* Fri Jan 23 2009 Paul Howarth <paul@city-fan.org> 1:1.1.8-3.0.CF
- rebuild for new MySQL in Rawhide

* Thu Jan 15 2009 Paul Howarth <paul@city-fan.org> 1:1.1.8-2.0.CF
- dovecot updated to 1.1.8
- added managesieve support (thanks Helmut K. C. Tessarek)
- add individual epochs for dovecot, sieve, and manage_sieve since Fedora
  uses the same EVR for all three and I stick to upstream version numbers
- update autotools patch

* Mon Dec 22 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-2.1.CF
- update dovecot-sieve to 1.1.6

* Wed Dec  3 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-2.0.CF
- revert changes from 1:1.1.6-2.0.CF; password can be stored in different file
  readable only for root via !include_try directive if required

* Mon Nov 24 2008 Paul Howarth <paul@city-fan.org> 1:1.1.7-1.0.CF
- update to 1.1.7
- remove dovecot-1.1-default-settings-passwd.patch, no longer needed
- tweak default-settings and SSLDIR patches to apply without fuzz

* Wed Nov  5 2008 Paul Howarth <paul@city-fan.org> 1:1.1.6-2.0.CF
- changed comment in sysconfig to match actual state
- change permissions of deliver (now sgid) and dovecot.conf to prevent
  possible password exposure

* Thu Oct 30 2008 Paul Howarth <paul@city-fan.org> 1:1.1.6-1.0.CF
- update to 1.1.6

* Thu Oct 23 2008 Paul Howarth <paul@city-fan.org> 1:1.1.5-1.0.CF
- update to 1.1.5

* Mon Oct  6 2008 Paul Howarth <paul@city-fan.org> 1:1.1.4-1.0.CF
- update to 1.1.4

* Tue Sep  2 2008 Paul Howarth <paul@city-fan.org> 1:1.1.3-1.0.CF
- update to 1.1.3
- update autotools patch

* Wed Jul 30 2008 Paul Howarth <paul@city-fan.org> 1:1.1.2-2.0.CF
- add option from Rawhide to prompt for SSL key password at startup

* Mon Jul 28 2008 Paul Howarth <paul@city-fan.org> 1:1.1.2-1.0.CF
- update to 1.1.2
- update autotools patch
- de-fuzz SSLDIR and login-dir patches
- explicitly specify version and release for all subpackages, in the hope of
  getting rpmbuild to use the correct buildroot directory name
- new sample config: dovecot-db-example.conf
- new plugin: zlib_plugin.so
- new utility: maildirlock
- new buildreq bzip2-devel

* Fri Jun 27 2008 Paul Howarth <paul@city-fan.org> 1:1.1.1-2.0.CF
- update default settings to listen on both IPv4 and IPv6 instead of IPv6 only
- tweak dist tag macros to work on current Rawhide with three-part releasenum

* Sun Jun 22 2008 Paul Howarth <paul@city-fan.org> 1:1.1.1-1.0.CF
- update to 1.1.1

* Sat Jun 21 2008 Paul Howarth <paul@city-fan.org> 1:1.1.0-1.0.CF
- update to upstream version 1.1.0 (with new source URL)
- update sieve plugin to 1.1.5
- remove unnecessary patches
- enable ldap and gssapi (where possible) plugins
- change ownership of dovecot.conf (resolves #452088)

* Wed Jun 18 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-9.0.CF
- update init script (resolves #451838); big release bump keeps up with
  Fedora 8 and 9 updates to maintain upgrade path

* Thu Jun  5 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-2.0.CF
- install convert-tool (resolves #450010)

* Tue Jun  3 2008 Paul Howarth <paul@city-fan.org> 1:1.0.14-1.0.CF
- update to 1.0.14
- update autotools patch

* Wed May 21 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-8.0.CF
- LSB-ize initscript (#238018)
- install dovecot.conf not world-readable (#445200)
- merge misc spec file cleanups from Rawhide
- rationalize scriptlets (#225708)

* Mon May 19 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-6.1.CF
- update sieve to 1.0.3

* Mon Mar 10 2008 Paul Howarth <paul@city-fan.org> 1:1.0.13-6.0.CF
- update to 1.0.13

* Wed Mar  5 2008 Paul Howarth <paul@city-fan.org> 1:1.0.12-1.0.CF
- update to 1.0.12

* Tue Mar  4 2008 Paul Howarth <paul@city-fan.org> 1:1.0.11-1.0.CF
- update to 1.0.11

* Tue Feb 26 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-5.0.CF
- rebuild for gcc 4.3.0 on Fedora 9

* Fri Jan 11 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-4.0.CF
- rebuild

* Wed Jan  2 2008 Paul Howarth <paul@city-fan.org> 1:1.0.10-1.0.CF
- Update to 1.0.10

* Wed Dec 12 2007 Paul Howarth <paul@city-fan.org> 1:1.0.9-1.0.CF
- Update to 1.0.9

* Fri Dec  7 2007 Paul Howarth <paul@city-fan.org> 1:1.0.8-1.1.CF
- Rebuild for new openldap and openssl in Rawhide

* Thu Nov 29 2007 Paul Howarth <paul@city-fan.org> 1:1.0.8-1.0.CF
- Update to 1.0.8

* Tue Nov  6 2007 Paul Howarth <paul@city-fan.org> 1:1.0.7-2.1.CF
- Add the winbind patch (#286351)
- Update autotools patch

* Wed Oct 31 2007 Paul Howarth <paul@city-fan.org> 1:1.0.7-1.1.CF
- Update to 1.0.7

* Mon Oct 29 2007 Paul Howarth <paul@city-fan.org> 1:1.0.6-1.1.CF
- Update to 1.0.6
- Update autotools patch
- Wiki snapshot now installed in correct directory upstream, so no need to
  move it in %%install

* Mon Oct  1 2007 Paul Howarth <paul@city-fan.org> 1:1.0.5-1.1.CF
- Fedora version has epoch bump, so mine must do too (grr...)

* Mon Sep 10 2007 Paul Howarth <paul@city-fan.org> 1.0.5-20.CF
- update to 1.0.5
- update download URL for dovecot
- update license tags
- make sure all documentation is UTF8

* Tue Aug  7 2007 Paul Howarth <paul@city-fan.org> 1.0.3-20.CF
- update to 1.0.3
- update autotools patch
- add quota-warning patch

* Fri Jul 20 2007 Paul Howarth <paul@city-fan.org> 1.0.2-22.CF
- update dovecot-sieve to 1.0.2

* Mon Jul 16 2007 Paul Howarth <paul@city-fan.org> 1.0.2-21.CF
- update to 1.0.2

* Mon Jun 18 2007 Paul Howarth <paul@city-fan.org> 1.0.1-20.CF
- update to 1.0.1
- specfile merge from Rawhide
  - new SQL split patch
  - split SQL libraries to separate packages

* Mon Apr 16 2007 Paul Howarth <paul@city-fan.org> 1.0.0-11.CF
- update to 1.0.0 (at last!)

* Fri Apr 13 2007 Paul Howarth <paul@city-fan.org> 1.0-0.10.CF.rc32
- update to 1.0.rc32

* Tue Apr 10 2007 Paul Howarth <paul@city-fan.org> 1.0-0.9.CF.rc31
- update to 1.0.rc31
- use --disable-dependency-tracking with configure script for faster builds
- add devel subpackage with headers for plugin writers

* Mon Apr  2 2007 Paul Howarth <paul@city-fan.org> 1.0-0.9.CF.rc29
- update to 1.0.rc29
- only rename the login dir on old distributions (FC4, RHEL4 and older) that
  don't clean up /var/run/dovecot properly
- build sieve plugin and package it in sieve subpackage
- preserve timestamps in installed data files where possible
- add --with-{doc,gssapi,inotify} configure options where appropriate
- package REDHAT-FAQ.txt
- move certificate generation script from %%{docdir} to %%{_libexecdir}

* Mon Mar 26 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc28
- update to 1.0.rc28
- put example configurations in %%{docdir} rather than %%{_sysconfdir}

* Thu Mar 15 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc27
- update to 1.0.rc27

* Wed Mar  7 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc26
- update to 1.0.rc26

* Fri Mar  2 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc25
- update to 1.0.rc25

* Fri Feb 23 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc24
- update to 1.0.rc24

* Wed Feb 21 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc23
- update to 1.0.rc23

* Wed Feb  7 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc22
- update to 1.0.rc22

* Mon Feb  5 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc21
- update to 1.0.rc21
- fix dist tag for fc7 onwards

* Wed Jan 24 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc19
- update to 1.0.rc19

* Mon Jan  8 2007 Paul Howarth <paul@city-fan.org> 1.0-0.8.CF.rc17
- update to 1.0.rc17

* Wed Dec 13 2006 Paul Howarth <paul@city-fan.org> 1.0-0.7.CF.rc15
- update to 1.0.rc15

* Mon Oct 16 2006 Paul Howarth <paul@city-fan.org> 1.0-0.6.CF.rc9
- update to 1.0.rc9

* Tue Oct 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.5.CF.rc8
- update to 1.0.rc8
- update default-settings patch

* Tue Oct  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.4.CF.rc7
- rebuilt for unwind info generation, broken in gcc-4.1.1-21

* Wed Sep 27 2006 Paul Howarth <paul@city-fan.org> 1.0-0.3.CF.rc7
- do not run over symlinked certificates in new locations on upgrade

* Thu Sep  7 2006 Paul Howarth <paul@city-fan.org> 1.0-0.2.CF.rc7
- fix distribution tags for development releases

* Fri Aug 18 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc7
- update to 1.0.rc7

* Tue Aug  8 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc6
- update to 1.0.rc6

* Thu Aug  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc5
- update to 1.0.rc5
- update default-settings patch

* Wed Jul  5 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc2
- update to 1.0.rc2
- update default-settings patch

* Wed Jun 28 2006 Paul Howarth <paul@city-fan.org> 1.0-0.1.CF.rc1
- update to 1.0.rc1
- update default-settings patch
- shuffle bits of release tag around for saner upgrade path
- note that parts (dovecot-auth, lib-sql and lib-ntlm) are now MIT licensed
- DH parameters generated in new %%{_localstatedir}/lib/dovecot directory

* Wed Jun 14 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta9.CF.1
- update to 1.0.beta9
- update default-settings patch
- don't apply pam-setcred patch as it should no longer be needed

* Fri May 12 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta8.1
- update to 1.0.beta8
- drop lib64 patch, should no longer be needed

* Wed May  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta7.1
- update to 1.0.beta7
- update default settings and lib64 patches to apply against beta7

* Fri Mar  3 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta3.2
- fix #182240 by looking in lib64 for libs first and then lib
  (more complete fix than rawhide beta2 patch; also, this package was not
  affected by the missing sample configuration files issue)

* Fri Feb 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta3.1
- update to 1.0.beta3
- move %%{_localstatedir}/run/dovecot/login back to
  %%{_localstatedir}/run/dovecot-login to avoid spurious boot-time error
  messages about not being able to clear %%{_localstatedir}/run/dovecot
- use complete Fedora patch set and then apply our own patches
- change the compiled-in defaults and adjust the default's configfile
  commented-out example settings to match compiled-in defaults,
  instead of changing the defaults only in the configfile, as per #179432
- fix #179574 by providing a default uidl_format for pop3
- half-fix #179620 by having plaintext auth enabled by default... this
  needs more thinking (which one we really want) and documentation
  either way
- don't fiddle with autotools input files, work around install issues
  manually; this removes the dependencies on autotools and allows the package
  to build on much older distributions
- change %%post as main dovecot binary no longer generates DH SSL parameters

* Wed Feb  1 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.3
- move /var/run/dovecot-login to %%{_localstatedir}/run/dovecot/login
- call dovecot --build-ssl-parameters in postinst (#179430)

* Tue Jan 31 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.2
- sort out gettext buildreq to enable builds on older distributions
  (still work to do to get autotools working though)
- update distribution-detection code to enable builds on CentOS
- update URL

* Mon Jan 23 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta2.1
- update to 1.0.beta2

* Tue Jan 17 2006 Paul Howarth <paul@city-fan.org> 1.0-0.beta1.1
- update to 1.0.beta1

* Tue Jan 10 2006 Paul Howarth <paul@city-fan.org> 1.0-0.alpha5.1
- update to 1.0.alpha5
- update dovecot.conf patch to apply against 1.0.alpha5
- include plugins

* Wed Dec 14 2005 Paul Howarth <paul@city-fan.org> 1.0-0.alpha4.1
- general spec file rewrite
- don't require specific openssl version
- determine ssldir at build time for compatibility with more distro versions
- use --with options for mysql and postgresql rather than regular macros
- initscript is not %%config
- %%{docdir}/examples/mkcert.sh is used in %%post and cannot therefore be %%doc

* Thu Nov 24 2005 Willem Riede <wriede@riede.org>
- merge from fc5t1 dovecot 0.99.14 srpm

* Sat Oct 22 2005 Willem Riede <wriede@riede.org>
- use newly released alpha4

* Thu Aug 18 2005 Willem Riede <wriede@riede.org>
- use newly released alpha1

* Sun Jul 24 2005 Willem Riede <wriede@riede.org>
- Merge FC4 .spec with ATRPM and use latest stable

* Fri Apr 22 2005 John Dennis <jdennis@redhat.com> 0.99.14-4.fc4
- openssl moved its certs, CA, etc. from /usr/share/ssl to /etc/pki

* Tue Apr 12 2005 Tom Lane <tgl@redhat.com> 0.99.14-3.fc4
- Rebuild for Postgres 8.0.2 (new libpq major version).

* Mon Mar  7 2005 John Dennis <jdennis@redhat.com> 0.99.14-2.fc4
- bump rev for gcc4 build

* Mon Feb 14 2005 John Dennis <jdennis@redhat.com> 0.99.14-1.fc4
- fix bug #147874, update to 0.99.14 release

* Wed Feb  2 2005 John Dennis <jdennis@redhat.com> 0.99.13-4.devel
- fix bug #146198, clean up temp kerberos tickets

* Mon Jan 17 2005 John Dennis <jdennis@redhat.com> 0.99.13-3.devel
- fix bug #145214, force mbox_locks to fcntl only
- fix bug #145241, remove prereq on postgres and mysql, allow rpm auto
  dependency generator to pick up client lib dependency if needed.

* Thu Jan 13 2005 John Dennis <jdennis@redhat.com> 0.99.13-2.devel
- make postgres & mysql conditional build
- remove execute bit on migration example scripts so rpm does not pull
  in additional dependences on perl and perl modules that are not present
  in dovecot proper.
- add REDHAT-FAQ.txt to doc directory

* Thu Jan  6 2005 John Dennis <jdennis@redhat.com> 0.99.13-1.devel
- bring up to date with latest upstream, 0.99.13, bug #143707
  also fix bug #14462, bad dovecot-uid macro name

* Thu Jan  6 2005 John Dennis <jdennis@redhat.com> 0.99.11-10.devel
- fix bug #133618, removed LITERAL+ capability from capability string

* Wed Jan  5 2005 John Dennis <jdennis@redhat.com> 0.99.11-9.devel
- fix bug #134325, stop dovecot during installation

* Wed Jan  5 2005 John Dennis <jdennis@redhat.com> 0.99.11-8.devel
- fix bug #129539, dovecot starts too early,
  set chkconfig to 65 35 to match cyrus-imapd
- also delete some old commented out code from SSL certificate creation

* Thu Dec 23 2004 John Dennis <jdennis@redhat.com> 0.99.11-7.devel
- add UW to Dovecot migration documentation and scripts, bug #139954
  fix SSL documentation and scripts, add missing documentation, bug #139276

* Fri Dec 17 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 1.0-test58.

* Tue Dec  7 2004 Axel Thimm <Axel.Thimm@ATrpms.net>
- Update to 1.0-test56.

* Mon Nov 15 2004 Warren Togami <wtogami@redhat.com> 0.99.11-2.FC4.1
- rebuild against MySQL4

* Thu Oct 21 2004 John Dennis <jdennis@redhat.com>
- fix bug #136623
  Change License field from GPL to LGPL to reflect actual license

* Thu Sep 30 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.3
- fix bug #124786, listen to ipv6 as well as ipv4

* Wed Sep  8 2004 John Dennis <jdennis@redhat.com> 0.99.11-1.FC3.1
- bring up to latest upstream,

* Wed Aug  4 2004 John Dennis <jdennis@redhat.com>
- change release field separator from comma to dot, bump build number

* Mon Aug  2 2004 John Dennis <jdennis@redhat.com> 0.99.10.9-1.FC3.1
- bring up to date with latest upstream, fixes include:
- LDAP support compiles now with Solaris LDAP library
- IMAP BODY and BODYSTRUCTURE replies were wrong for MIME parts which
  didn't contain Content-Type header.
- MySQL and PostgreSQL auth didn't reconnect if connection was lost
  to SQL server
- Linking fixes for dovecot-auth with some systems
- Last fix for disconnecting client when downloading mail longer than
  30 seconds actually made it never disconnect client. Now it works
  properly: disconnect when client hasn't read _any_ data for 30
  seconds.
- MySQL compiling got broken in last release
- More PostgreSQL reconnection fixing

* Mon Jul 26 2004 John Dennis <jdennis@redhat.com> 0.99.10.7-1,FC3,1
- enable postgres and mySQL in build
- fix configure to look for mysql in alternate locations
- nuke configure script in tar file, recreate from configure.in using autoconf

- bring up to latest upstream, which included:
- Added outlook-pop3-no-nuls workaround to fix Outlook hang in mails with NULs.
- Config file lines can now contain quoted strings ("value ")
- If client didn't finish downloading a single mail in 30 seconds,
  Dovecot closed the connection. This was supposed to work so that
  if client hasn't read data at all in 30 seconds, it's disconnected.
- Maildir: LIST now doesn't skip symlinks


* Wed Jun 30 2004 John Dennis <jdennis@redhat.com>
- bump rev for build
- change rev for FC3 build

* Fri Jun 25 2004 John Dennis <jdennis@redhat.com> 0.99.10.6-1
- bring up to date with upstream,
  recent change log comments from Timo Sirainen were:
  SHA1 password support using OpenSSL crypto library
  mail_extra_groups setting
  maildir_stat_dirs setting
  Added NAMESPACE capability and command
  Autocreate missing maildirs (instead of crashing)
  Fixed occasional crash in maildir synchronization
  Fixed occasional assertion crash in ioloop.c
  Fixed FreeBSD compiling issue
  Fixed issues with 64bit Solaris binary

* Tue Jun 15 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Thu May 27 2004 David Woodhouse <dwmw2@redhat.com> 0.99.10.5-1
- Update to 0.99.10.5 to fix maildir segfaults (#123022)

* Fri May 07 2004 Warren Togami <wtogami@redhat.com> 0.99.10.4-4
- default auth config that is actually usable
- Timo Sirainen (author) suggested functionality fixes
  maildir, imap-fetch-body-section, customflags-fix

* Mon Feb 23 2004 Tim Waugh <twaugh@redhat.com>
- Use ':' instead of '.' as separator for chown.

* Tue Feb 17 2004 Jeremy Katz <katzj@redhat.com> 0.99.10.4-3
- restart properly if it dies (#115594)

* Fri Feb 13 2004 Elliot Lee <sopwith@redhat.com>
- rebuilt

* Mon Nov 24 2003 Jeremy Katz <katzj@redhat.com> 0.99.10.4-1
- update to 0.99.10.4

* Mon Oct  6 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-7
- another patch from upstream to fix returning invalid data on partial 
  BODY[part] fetches
- patch to avoid confusion of draft/deleted in indexes

* Tue Sep 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-6
- add some patches from upstream (#104288)

* Thu Sep  4 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-5
- fix startup with 2.6 with patch from upstream (#103801)

* Tue Sep  2 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-4
- fix assert in search code (#103383)

* Tue Jul 22 2003 Nalin Dahyabhai <nalin@redhat.com> 0.99.10-3
- rebuild

* Thu Jul 17 2003 Bill Nottingham <notting@redhat.com> 0.99.10-2
- don't run by default

* Thu Jun 26 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-1
- 0.99.10

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.2
- 0.99.10-rc2 (includes ssl detection fix)
- a few tweaks from fedora
  - noreplace the config file
  - configure --with-ldap to get LDAP enabled

* Mon Jun 23 2003 Jeremy Katz <katzj@redhat.com> 0.99.10-0.1
- 0.99.10-rc1
- add fix for ssl detection
- add zlib-devel to BuildRequires
- change pam service name to dovecot
- include pam config

* Thu May  8 2003 Jeremy Katz <katzj@redhat.com> 0.99.9.1-1
- update to 0.99.9.1
- add patch from upstream to fix potential bug when fetching with 
  CR+LF linefeeds
- tweak some things in the initscript and config file noticed by the 
  fedora folks

* Sun Mar 16 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-2
- fix ssl dir
- own /var/run/dovecot/login with the correct perms
- fix chmod/chown in post

* Fri Mar 14 2003 Jeremy Katz <katzj@redhat.com> 0.99.8.1-1
- update to 0.99.8.1

* Tue Mar 11 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-2
- add a patch to fix quoting problem from CVS

* Mon Mar 10 2003 Jeremy Katz <katzj@redhat.com> 0.99.8-1
- 0.99.8
- add some buildrequires
- fixup to build with openssl 0.9.7
- now includes a pop3 daemon (off by default)
- clean up description and %%preun
- add dovecot user (uid/gid of 97)
- add some buildrequires
- move the ssl cert to %%{_datadir}/ssl/certs
- create a dummy ssl cert in %%post
- own /var/run/dovecot
- make the config file a source so we get default mbox locks of fcntl

* Sun Dec  1 2002 Seth Vidal <skvidal@phy.duke.edu>
- 0.99.4 and fix startup so it starts imap-master not vsftpd :)

* Tue Nov 26 2002 Seth Vidal <skvidal@phy.duke.edu>
- first build
